@@ -12,35 +12,21 @@ utils::globalVariables("pv")
 #'                
 #' @seealso \code{\link{sjt.grpmean}}
 #'                
-#' @param depVar dependent variable. Will be used with following formula:
-#'          \code{aov(depVar ~ grpVar)}
-#' @param grpVar grouping variable, as unordered factor. Will be used with following formula:
-#'          \code{aov(depVar ~ grpVar)}
+#' @param var.dep dependent variable. Will be used with following formula:
+#'          \code{aov(var.dep ~ var.grp)}
+#' @param var.grp factor with the cross-classifying variable, where \code{var.dep} 
+#'          is grouped into the categories represented by \code{var.grp}.
 #' @param meansums logical, if \code{TRUE}, the values reported are the true group mean values (see also \code{\link{sjt.grpmean}}).
 #'          If \code{FALSE} (default), the values are reported in the standard way, i.e. the values indicate the difference of
 #'          the group mean in relation to the intercept (reference group).
-#' @param axisLabels.y character vector, indicating the value labels of \code{grpVar} that 
-#'          are used for labelling the axis. See 'Examples'.
-#' @param reverseOrder logical, if \code{TRUE}, the order of categories (groups) is reversed.
-#'          Default is \code{FALSE}.
-#' @param stringIntercept string that indicates the reference group (intercept), that is appended to
+#' @param string.interc string that indicates the reference group (intercept), that is appended to
 #'          the value label of the grouping variable. Default is \code{"(Intercept)"}.
-#' @param axisLimits numeric vector of length 2, defining the range of the plot axis.
-#'          By default, the limits range from the lowest confidence interval to the 
-#'          highest, so plot has maximum zoom.
-#' @param geom.colors vector of length two, indicating the colors of the points; 
-#'          first value is for groups with positive means and the second for 
-#'          negative means.
-#' @param geom.size size of the points. Default is 3.
-#' @param showValueLabels logical, whether the value labels (mean differences) should be plotted 
-#'          to each dot or not.
-#' @param showModelSummary logical, if \code{TRUE}, a summary of the anova model with 
-#'          Sum of Squares between groups (ssb), Sum of Squares within groups (ssw), multiple and adjusted 
-#'          R-square and F-Test is printed to the lower right corner
-#'          of the diagram. Default is \code{TRUE}.
 #'          
 #' @inheritParams sjp.grpfrq
 #' @inheritParams sjp.lm
+#' @inheritParams sjp.glmer
+#' @inheritParams sjp.xtab
+#' @inheritParams sjp.gpt
 #'          
 #' @return (Insisibily) returns the ggplot-object with the complete plot (\code{plot}) as well as the data frame that
 #'           was used for setting up the ggplot-object (\code{df}).
@@ -48,7 +34,7 @@ utils::globalVariables("pv")
 #' @examples
 #' library(sjmisc)
 #' data(efc)
-#' # note: "grpVar" does not need to be a factor.
+#' # note: "var.grp" does not need to be a factor.
 #' # coercion to factor is done by the function
 #' sjp.aov1(efc$c12hour, efc$e42dep)
 #' 
@@ -58,90 +44,80 @@ utils::globalVariables("pv")
 #' @importFrom stats confint aov summary.lm
 #' @importFrom dplyr add_rownames
 #' @export
-sjp.aov1 <- function(depVar,
-                     grpVar,
+sjp.aov1 <- function(var.dep,
+                     var.grp,
                      meansums = FALSE,
                      title = NULL,
-                     axisLabels.y = NULL,
-                     reverseOrder = FALSE,
-                     stringIntercept = "(Intercept)",
-                     showAxisLabels.y = TRUE,
-                     axisTitle.x = "",
-                     axisLimits = NULL,
+                     axis.labels = NULL,
+                     rev.order = FALSE,
+                     string.interc = "(Intercept)",
+                     axis.title = "",
+                     axis.lim = NULL,
                      geom.colors = c("#3366a0", "#aa3333"),
                      geom.size = 3,
-                     breakTitleAt = 50,
-                     breakLabelsAt = 25,
-                     gridBreaksAt = NULL,
-                     expand.grid = FALSE,
-                     showValueLabels = TRUE,
-                     labelDigits = 2,
+                     wrap.title = 50,
+                     wrap.labels = 25,
+                     grid.breaks = NULL,
+                     show.values = TRUE,
+                     digits = 2,
                      y.offset = .1,
-                     showPValueLabels = TRUE,
-                     showModelSummary = FALSE,
-                     printPlot = TRUE) {
+                     show.p = TRUE,
+                     show.summary = FALSE,
+                     prnt.plot = TRUE) {
   # --------------------------------------------------------
   # get variable name
   # --------------------------------------------------------
-  grpVar.name <- get_var_name(deparse(substitute(grpVar)))
-  depVar.name <- get_var_name(deparse(substitute(depVar)))
+  var.grp.name <- get_var_name(deparse(substitute(var.grp)))
+  var.dep.name <- get_var_name(deparse(substitute(var.dep)))
   # --------------------------------------------------------
   # try to automatically set labels is not passed as parameter
   # --------------------------------------------------------
-  if (is.null(axisLabels.y)) axisLabels.y <- sjmisc::get_labels(grpVar, 
-                                                                attr.only = F,
-                                                                include.values = NULL,
-                                                                include.non.labelled = T)
-  if (is.null(axisTitle.x)) axisTitle.x <- sjmisc::get_label(depVar, def.value = depVar.name)
+  if (is.null(axis.labels)) axis.labels <- sjmisc::get_labels(var.grp, 
+                                                              attr.only = F,
+                                                              include.values = NULL,
+                                                              include.non.labelled = T)
+  if (is.null(axis.title)) axis.title <- sjmisc::get_label(var.dep, def.value = var.dep.name)
   if (is.null(title)) {
-    t1 <- sjmisc::get_label(grpVar, def.value = grpVar.name)
-    t2 <- sjmisc::get_label(depVar, def.value = depVar.name)
+    t1 <- sjmisc::get_label(var.grp, def.value = var.grp.name)
+    t2 <- sjmisc::get_label(var.dep, def.value = var.dep.name)
     if (!is.null(t1) && !is.null(t2)) title <- paste0(t1, " by ", t2)
   }
   # --------------------------------------------------------
   # remove titles if empty
   # --------------------------------------------------------
-  if (!is.null(axisLabels.y) && axisLabels.y == "") axisLabels.y <- NULL
-  if (!is.null(axisTitle.x) && axisTitle.x == "") axisTitle.x <- NULL  
+  if (!is.null(axis.labels) && axis.labels == "") axis.labels <- NULL
+  if (!is.null(axis.title) && axis.title == "") axis.title <- NULL  
   if (!is.null(title) && title == "") title <- NULL    
   # --------------------------------------------------------
   # unlist labels
   # --------------------------------------------------------
-  if (!is.null(axisLabels.y)) {
+  if (!is.null(axis.labels)) {
     # append "intercept" string, to mark the reference category
-    axisLabels.y[1] <- paste(axisLabels.y[1], stringIntercept)
+    axis.labels[1] <- paste(axis.labels[1], string.interc)
   }
   # --------------------------------------------------------
-  # Check if grpVar is factor. If not, convert to factor
+  # Check if var.grp is factor. If not, convert to factor
   # --------------------------------------------------------
-  if (!is.factor(grpVar)) grpVar <- as.factor(grpVar)
-  # --------------------------------------------------------
-  # Check spelling of type-param
-  # --------------------------------------------------------
-  if (isTRUE(expand.grid)) 
-    expand.grid <- ggplot2::waiver()
-  else
-    expand.grid <- c(0, 0)
+  if (!is.factor(var.grp)) var.grp <- as.factor(var.grp)
   # --------------------------------------------------------
   # check whether we have x-axis title. if not, use standard
   # value
   # --------------------------------------------------------
-  if (is.null(axisTitle.x)) axisTitle.x <- c("")
   # check length of diagram title and split longer string at into new lines
   # every 50 chars
-  if (!is.null(title)) title <- sjmisc::word_wrap(title, breakTitleAt)
+  if (!is.null(title)) title <- sjmisc::word_wrap(title, wrap.title)
   # check length of x-axis title and split longer string at into new lines
   # every 50 chars
-  if (!is.null(axisTitle.x)) axisTitle.x <- sjmisc::word_wrap(axisTitle.x, breakTitleAt)
+  if (!is.null(axis.title)) axis.title <- sjmisc::word_wrap(axis.title, wrap.title)
   # check length of x-axis-labels and split longer strings at into new lines
   # every 10 chars, so labels don't overlap
-  if (!is.null(axisLabels.y)) axisLabels.y <- sjmisc::word_wrap(axisLabels.y, breakLabelsAt)
+  if (!is.null(axis.labels)) axis.labels <- sjmisc::word_wrap(axis.labels, wrap.labels)
   # ----------------------------
   # Calculate one-way-anova. Since we have
   # only one group variable, Type of SS does
   # not matter.
   # ----------------------------
-  fit <- stats::aov(depVar ~ grpVar)
+  fit <- stats::aov(var.dep ~ var.grp)
   # coefficients (group mean)
   means <- stats::summary.lm(fit)$coefficients[, 1]
   # p-values of means
@@ -166,7 +142,7 @@ sjp.aov1 <- function(depVar,
   # create expression with model summarys. used
   # for plotting in the diagram later
   # ----------------------------
-  if (showModelSummary) {
+  if (show.summary) {
     # sum of squares
     ss <- summary(fit)[[1]]['Sum Sq']
     # multiple r2
@@ -193,14 +169,14 @@ sjp.aov1 <- function(depVar,
   # print coefficients and p-values in plot
   # ----------------------------
   # init data column for p-values
-  ps <- c(round(means, labelDigits))
+  ps <- c(round(means, digits))
   # if no values should be shown, clear
   # vector now
-  if (!showValueLabels) ps <- rep(c(""), length(ps))
+  if (!show.values) ps <- rep("", length(ps))
   # --------------------------------------------------------
   # copy p-values into data column
   # --------------------------------------------------------
-  if (showPValueLabels) {
+  if (show.p) {
     for (i in 1:length(means.p)) {
       ps[i] <- sjmisc::trim(paste(ps[i], get_p_stars(means.p[i])))
     }  
@@ -209,7 +185,7 @@ sjp.aov1 <- function(depVar,
   # check whether order of category items should be reversed
   # or not
   # --------------------------------------------------------
-  if (reverseOrder)
+  if (rev.order)
     catorder <- c(length(means):1)
   else
     catorder <- c(1:length(means))
@@ -227,9 +203,9 @@ sjp.aov1 <- function(depVar,
   # check if user defined labels have been supplied
   # if not, use variable names from data frame
   # --------------------------------------------------------
-  if (is.null(axisLabels.y)) axisLabels.y <- row.names(df)
+  if (is.null(axis.labels)) axis.labels <- row.names(df)
   # order labels
-  axisLabels.y <- axisLabels.y[catorder]
+  axis.labels <- axis.labels[catorder]
   # give columns names
   names(df) <- c("means", "lower", "upper", "p", "pv", "xv")
   df$means <- sjmisc::to_value(df$means, keep.labels = F)
@@ -242,10 +218,10 @@ sjp.aov1 <- function(depVar,
   df <- cbind(df, geocol = ifelse(df$means >= 0, geom.colors[1], geom.colors[2]))
   # --------------------------------------------------------
   # Calculate axis limits. The range is from lowest lower-CI
-  # to highest upper-CI, or a user-defined range (if "axisLimits"
+  # to highest upper-CI, or a user-defined range (if "axis.lim"
   # is not NULL)
   # --------------------------------------------------------
-  if (is.null(axisLimits)) {
+  if (is.null(axis.lim)) {
     # we have confindence intervals displayed, so
     # the range corresponds to the boundaries given by
     # the CI's
@@ -258,15 +234,14 @@ sjp.aov1 <- function(depVar,
     upper_lim <- ifelse(maxval == 0, 0, limfac * ceiling((maxval + 1) / limfac))
     lower_lim <- ifelse(minval == 0, 0, limfac * floor(minval / limfac))
   } else {
-    lower_lim <- axisLimits[1]
-    upper_lim <- axisLimits[2]
+    lower_lim <- axis.lim[1]
+    upper_lim <- axis.lim[2]
   }
   # determine gridbreaks
-  if (is.null(gridBreaksAt))
+  if (is.null(grid.breaks))
     ticks <- pretty(c(lower_lim, upper_lim))
   else
-    ticks <- c(seq(lower_lim, upper_lim, by = gridBreaksAt))
-  if (!showAxisLabels.y) axisLabels.y <- c("")
+    ticks <- c(seq(lower_lim, upper_lim, by = grid.breaks))
   # --------------------------------------------------------
   # Set up plot padding (margins inside diagram)
   # --------------------------------------------------------
@@ -276,39 +251,33 @@ sjp.aov1 <- function(depVar,
   # --------------------------------------------------------
   # Start plot here!
   # --------------------------------------------------------
-  anovaplot <- ggplot(df, aes(y = means, x = xv)) +
+  anovaplot <- ggplot(df, aes(y = means, x = as.factor(xv))) +
     # print point
     geom_point(size = geom.size, colour = df$geocol) +
     # and error bar
-    geom_errorbar(aes(ymin = lower, ymax = upper), 
-                  colour = df$geocol, 
-                  width = 0) +
+    geom_errorbar(aes(ymin = lower, ymax = upper), colour = df$geocol, width = 0) +
     # Print p-values. With vertical adjustment, so 
     # they don't overlap with the errorbars
-    geom_text(aes(label = pv, y = means), 
-              nudge_x = y.offset, 
-              show.legend = FALSE) +
+    geom_text(aes(label = pv, y = means), nudge_x = y.offset, show.legend = FALSE) +
     # set y-scale-limits, breaks and tick labels
     scaley +
     # set value labels to x-axis
-    scale_x_discrete(labels = axisLabels.y, limits = c(1:nrow(df))) +
+    scale_x_discrete(labels = axis.labels, limits = 1:length(axis.labels)) +
     # flip coordinates
-    labs(title = title, x = NULL, y = axisTitle.x) +
+    labs(title = title, x = NULL, y = axis.title) +
     coord_flip()
   # check whether modelsummary should be printed
-  if (showModelSummary) {
+  if (show.summary) {
     # add annotations with model summary
     # annotations include intercept-value and model's r-square
-    anovaplot <- anovaplot + annotate("text", 
-                                      label = modsum, 
-                                      parse = TRUE, 
-                                      x = -Inf, 
-                                      y = Inf)
+    anovaplot <- anovaplot + 
+      annotate("text", label = modsum, parse = TRUE, x = -Inf, y = Inf, 
+               hjust = "right", vjust = "bottom")
   }
   # ---------------------------------------------------------
   # Check whether ggplot object should be returned or plotted
   # ---------------------------------------------------------
-  if (printPlot) print(anovaplot)
+  if (prnt.plot) graphics::plot(anovaplot)
   # -------------------------------------
   # set proper column names
   # -------------------------------------
