@@ -1,7 +1,7 @@
 # bind global variables
 utils::globalVariables(c("OR", "lower", "upper", "p", "pa", "shape"))
 
-#' @title Plot odds or incidents ratios (forest plots) of multiple fitted glm(er)'s
+#' @title Plot estimates of multiple fitted glm(er)'s
 #' @name sjp.glmm
 #' 
 #' @description Plot and compare odds or incidents ratios (forest plots) of multiple fitted 
@@ -16,6 +16,7 @@ utils::globalVariables(c("OR", "lower", "upper", "p", "pa", "shape"))
 #' @inheritParams sjp.glm
 #' @inheritParams sjp.lm
 #' @inheritParams sjp.grpfrq
+#' @inheritParams sjt.lm
 #'          
 #' @note The fitted models may have differing predictors, but only in a 
 #'         "stepwise" sense; i.e., models should share a common set of predictors,
@@ -45,13 +46,8 @@ utils::globalVariables(c("OR", "lower", "upper", "p", "pa", "shape"))
 #' 
 #' # plot multiple models with legend labels and point shapes instead of value  labels
 #' sjp.glmm(fitOR1, fitOR2, fitOR3,
-#'          labelDependentVariables = c("Fertility", 
-#'                                      "Infant Mortality", 
-#'                                      "Agriculture"),
-#'          showValueLabels = FALSE,
-#'          showPValueLabels = FALSE,
-#'          fade.ns = TRUE,
-#'          usePShapes = TRUE)
+#'          depvar.labels = c("Fertility", "Infant Mortality", "Agriculture"),
+#'          show.values = FALSE, show.p = FALSE, fade.ns = TRUE, p.shape = TRUE)
 #' 
 #' # plot multiple models from nested lists argument
 #' all.models <- list()
@@ -61,7 +57,6 @@ utils::globalVariables(c("OR", "lower", "upper", "p", "pa", "shape"))
 #' 
 #' sjp.glmm(all.models)
 #' 
-#' 
 #' # -------------------------------
 #' # Predictors for negative impact
 #' # of care. Data from the EUROFAMCARE
@@ -73,19 +68,13 @@ utils::globalVariables(c("OR", "lower", "upper", "p", "pa", "shape"))
 #' # create binary response
 #' y <- ifelse(efc$neg_c_7 < median(na.omit(efc$neg_c_7)), 0, 1)
 #' # create dummy variables for educational status
-#' edu.mid <- ifelse(efc$c172code == 2, 1, 0)
-#' edu.high <- ifelse(efc$c172code == 3, 1, 0)
-#' # create data frame for fitted model
-#' mydat <- data.frame(y = as.factor(y),
-#'                     sex = as.factor(efc$c161sex),
-#'                     dep = as.factor(efc$e42dep),
-#'                     barthel = as.numeric(efc$barthtot),
-#'                     edu.mid = as.factor(edu.mid),
-#'                     edu.hi = as.factor(edu.high))
+#' mydf <- data.frame(y = as.factor(y),
+#'                    sex = efc$c161sex,
+#'                    dep = to_factor(efc$e42dep),
+#'                    barthel = efc$barthtot,
+#'                    education = to_factor(efc$c172code))
 #' 
-#' fit1 <- glm(y ~ sex + edu.mid + edu.hi, 
-#'             data = mydat, 
-#'             family = binomial(link = "logit"))
+#' fit1 <- glm(y ~ sex + education,  data = mydf, family = binomial(link = "logit"))
 #' fit2 <- update(fit1, . ~ . + barthel)
 #' fit3 <- update(fit2, . ~ . + dep)
 #' 
@@ -96,35 +85,34 @@ utils::globalVariables(c("OR", "lower", "upper", "p", "pa", "shape"))
 #' @importFrom stats na.omit coef confint
 #' @export
 sjp.glmm <- function(...,
+                     remove.estimates = NULL,
                      title = NULL,
-                     labelDependentVariables = NULL,
-                     legendDepVarTitle = "Dependent Variables",
-                     legendPValTitle = "p-level",
-                     axisLabels.y = NULL,
-                     axisTitle.x = "Odds Ratios",
-                     axisLimits = NULL,
-                     breakTitleAt = 50,
-                     breakLabelsAt = 25,
-                     breakLegendTitleAt = 20,
-                     gridBreaksAt = 0.5,
-                     transformTicks = TRUE,
+                     depvar.labels = NULL,
+                     legend.title = "Dependent Variables",
+                     legend.pval.title = "p-level",
+                     axis.labels = NULL,
+                     axis.title = "Estimates",
+                     axis.lim = NULL,
+                     wrap.title = 50,
+                     wrap.labels = 25,
+                     wrap.legend.title = 20,
+                     grid.breaks = 0.5,
+                     trns.ticks = TRUE,
                      geom.size = 3,
                      geom.spacing = 0.4,
                      geom.colors = "Set1",
+                     show.values = TRUE,
+                     show.legend = TRUE,
+                     show.intercept = FALSE,
+                     show.p = TRUE,
                      fade.ns = FALSE,
-                     usePShapes = FALSE,
-                     interceptLineType = 2,
-                     interceptLineColor = "grey70",
-                     remove.estimates = NULL,
-                     coord.flip = TRUE,
-                     showIntercept = FALSE,
-                     showAxisLabels.y = TRUE,
-                     showValueLabels = TRUE,
-                     labelDigits = 2,
-                     showPValueLabels = TRUE,
-                     hideLegend = FALSE,
+                     p.shape = FALSE,
+                     vline.type = 2,
+                     vline.color = "grey70",
+                     digits = 2,
                      facet.grid = FALSE,
-                     printPlot = TRUE) {
+                     coord.flip = TRUE,
+                     prnt.plot = TRUE) {
   # --------------------------------------------------------
   # retrieve list of fitted models
   # --------------------------------------------------------
@@ -144,22 +132,22 @@ sjp.glmm <- function(...,
   # ----------------------------
   # if we have no labels of dependent variables supplied, use a 
   # default string (Model) for legend
-  if (is.null(labelDependentVariables)) {
-    labelDependentVariables <- c()
+  if (is.null(depvar.labels)) {
+    depvar.labels <- c()
     for (i in seq_len(fitlength)) {
-      labelDependentVariables <- c(labelDependentVariables, 
-                                   get_model_response_label(input_list[[i]]))
+      depvar.labels <- c(depvar.labels, 
+                         get_model_response_label(input_list[[i]]))
     }
   }
   # check length of diagram title and split longer string at into new lines
-  if (!is.null(title)) title <- sjmisc::word_wrap(title, breakTitleAt)
+  if (!is.null(title)) title <- sjmisc::word_wrap(title, wrap.title)
   # check length of x-axis title and split longer string at into new lines
   # every 50 chars
-  if (!is.null(axisTitle.x)) axisTitle.x <- sjmisc::word_wrap(axisTitle.x, breakTitleAt)
+  if (!is.null(axis.title)) axis.title <- sjmisc::word_wrap(axis.title, wrap.title)
   # check length of dependent variables
-  if (!is.null(labelDependentVariables)) labelDependentVariables <- sjmisc::word_wrap(labelDependentVariables, breakLegendTitleAt)
+  if (!is.null(depvar.labels)) depvar.labels <- sjmisc::word_wrap(depvar.labels, wrap.legend.title)
   # check length of x-axis-labels and split longer strings at into new lines
-  if (!is.null(axisLabels.y)) axisLabels.y <- sjmisc::word_wrap(axisLabels.y, breakLabelsAt)
+  if (!is.null(axis.labels)) axis.labels <- sjmisc::word_wrap(axis.labels, wrap.labels)
   # ----------------------------
   # iterate all fitted models
   # ----------------------------
@@ -201,16 +189,16 @@ sjp.glmm <- function(...,
     # (i.e. are more transparent)
     palpha <- NULL
     for (i in 1:length(pv)) {
-      ps[i] <- c("")
+      ps[i] <- ""
       pointshapes[i] <- 1
       palpha[i] <- "s"
     }
     # ----------------------------
     # copy OR-values into data column
     # ----------------------------
-    if (showValueLabels) {
+    if (show.values) {
       for (i in 1:length(pv)) {
-        ps[i] <- sprintf("%.*f", labelDigits, ov[i])
+        ps[i] <- sprintf("%.*f", digits, ov[i])
       }
     }
     # ----------------------------
@@ -221,13 +209,13 @@ sjp.glmm <- function(...,
         pointshapes[i] <- 1
         palpha[i] <- "ns"
       } else if (pv[i] >= 0.01 && pv[i] < 0.05) {
-        if (showPValueLabels) ps[i] <- paste(ps[i], "*")
+        if (show.p) ps[i] <- paste(ps[i], "*")
         pointshapes[i] <- 2
       } else if (pv[i] >= 0.001 && pv[i] < 0.01) {
-        if (showPValueLabels) ps[i] <- paste(ps[i], "**")
+        if (show.p) ps[i] <- paste(ps[i], "**")
         pointshapes[i] <- 3
       } else {
-        if (showPValueLabels) ps[i] <- paste(ps[i], "***")
+        if (show.p) ps[i] <- paste(ps[i], "***")
         pointshapes[i] <- 4
       }
     }  
@@ -240,7 +228,7 @@ sjp.glmm <- function(...,
     # add rownames
     odds$term <- row.names(odds)
     #remove intercept from df
-    if (!showIntercept) odds <- odds[-1, ]
+    if (!show.intercept) odds <- odds[-1, ]
     # add data frame to final data frame
     finalodds <- rbind(finalodds, odds)
   }
@@ -273,15 +261,15 @@ sjp.glmm <- function(...,
     row.names(finalodds) <- keepnames
   }
   # set axis labels
-  if (is.null(axisLabels.y)) {
-    axisLabels.y <- unique(finalodds$term)
-    axisLabels.y <- axisLabels.y[order(unique(finalodds$xpos))]
+  if (is.null(axis.labels)) {
+    axis.labels <- unique(finalodds$term)
+    axis.labels <- axis.labels[order(unique(finalodds$xpos))]
   }
   # --------------------------------------------------------
   # Calculate axis limits. The range is from lowest lower-CI
   # to highest upper-CI, or a user defined range
   # --------------------------------------------------------
-  if (is.null(axisLimits)) {
+  if (is.null(axis.lim)) {
     # we have confindence intervals displayed, so
     # the range corresponds to the boundaries given by
     # the CI's
@@ -293,22 +281,21 @@ sjp.glmm <- function(...,
     # if we show p value labels, increase upper
     # limit of x axis, so labels are plotted inside
     # diagram range
-    if (showValueLabels || showPValueLabels) upper_lim <- upper_lim + 0.1
+    if (show.values || show.p) upper_lim <- upper_lim + 0.1
     # give warnings when auto-limits are very low/high
     if ((lower_lim < 0.1) || (upper_lim > 100)) {
-      warning("Exp. coefficients and/or exp. confidence intervals may be out of printable bounds. Consider using \"axisLimits\" argument!")
+      warning("Exp. coefficients and/or exp. confidence intervals may be out of printable bounds. Consider using `axis.lim` argument!")
     }
   } else {
     # Here we have user defind axis range
-    lower_lim <- axisLimits[1]
-    upper_lim <- axisLimits[2]
+    lower_lim <- axis.lim[1]
+    upper_lim <- axis.lim[2]
   }
   # --------------------------------------------------------
   # Define axis ticks, i.e. at which position we have grid
   # bars.
   # --------------------------------------------------------
-  ticks <- seq(lower_lim, upper_lim, by = gridBreaksAt)
-  if (!showAxisLabels.y) axisLabels.y <- c("")
+  ticks <- seq(lower_lim, upper_lim, by = grid.breaks)
   # --------------------------------------------------------
   # prepare star and shape values. we just copy those values
   # that are actually needed, so legend shapes are always 
@@ -335,7 +322,7 @@ sjp.glmm <- function(...,
   # first check, whether user wants different shapes for
   # different p-levels
   # --------------------------------------------------------
-  if (usePShapes) {
+  if (p.shape) {
     plotHeader <- plotHeader +
       # set shape aesthetic. we have to repeat the other aesthestics as well,
       # because otherwise the order of point shapes differes from the order
@@ -373,20 +360,20 @@ sjp.glmm <- function(...,
               show.legend = FALSE) +
     # Intercept-line
     geom_hline(yintercept = 1, 
-               linetype = interceptLineType, 
-               colour = interceptLineColor) +
+               linetype = vline.type, 
+               colour = vline.color) +
     labs(title = title, 
          x = NULL, 
-         y = axisTitle.x, 
-         shape = legendPValTitle, 
-         colour = legendDepVarTitle) +
-    scale_x_discrete(labels = axisLabels.y) +
+         y = axis.title, 
+         shape = legend.pval.title, 
+         colour = legend.title) +
+    scale_x_discrete(labels = axis.labels) +
     # use transparancy if requested, but hide legend
     scale_alpha_manual(values = c(nsAlpha, 1.0), guide = "none")
   # --------------------------------------------------------
   # create pretty breaks for log-scale
   # --------------------------------------------------------
-  if (transformTicks) {
+  if (trns.ticks) {
     # since the odds are plotted on a log-scale, the grid bars'
     # distance shrinks with higher odds values. to provide a visual
     # proportional distance of the grid bars, we can apply the
@@ -414,13 +401,13 @@ sjp.glmm <- function(...,
   # ---------------------------------------------------------
   plotHeader <- sj.setGeomColors(plotHeader, 
                                  geom.colors, 
-                                 length(labelDependentVariables), 
-                                 ifelse(isTRUE(hideLegend), FALSE, TRUE), 
-                                 labelDependentVariables)
+                                 length(depvar.labels), 
+                                 show.legend, 
+                                 depvar.labels)
   # ---------------------------------------------------------
   # Check whether ggplot object should be returned or plotted
   # ---------------------------------------------------------
-  if (printPlot) print(plotHeader)
+  if (prnt.plot) graphics::plot(plotHeader)
   # -------------------------------------
   # set proper column names
   # -------------------------------------
