@@ -13,86 +13,38 @@
 #'            \item \code{\link{sjt.pca}}
 #'            }
 #' 
-#' @param data A data frame with factors (each columns one variable) that should be used 
-#'          to compute a PCA, or a \code{\link{prcomp}} object.
-#' @param numberOfFactors A predefined number of factors to use for the calculating the varimax
-#'          rotation. By default, this value is \code{NULL} and the amount of factors is
-#'          calculated according to the Kaiser-criteria. See paramater \code{plotEigenvalues}.
-#' @param factorLoadingTolerance Specifies the minimum difference a variable needs to have between
-#'          factor loadings (components) in order to indicate a clear loading on just one factor and not
-#'          diffusing over all factors. For instance, a variable with 0.8, 0.82 and 0.84 factor loading 
-#'          on 3 possible factors can not be clearly assigned to just one factor and thus would be removed
-#'          from the principal component analysis. By default, the minimum difference of loading values
-#'          between the highest and 2nd highest factor should be 0.1
-#' @param plotEigenvalues If \code{TRUE}, a plot showing the Eigenvalues according to the
+#' @param plot.eigen If \code{TRUE}, a plot showing the Eigenvalues according to the
 #'          Kaiser criteria is plotted to determine the number of factors.
-#' @param digits The amount of decimals used. Default is 2.
-#' @param title Title of the diagram, plotted above the whole diagram panel.
-#' @param axisLabels.y The item labels that are printed on the y-axis. If no item labels are
-#'          provided (default), the data frame's column names are used. Item labels must
-#'          be a string vector, e.g.: \code{axisLabels.y = c("Var 1", "Var 2", "Var 3")}.
 #' @param type Plot type resp. geom type. May be one of following: \code{"circle"} or \code{"tile"} 
 #'          circular or tiled geoms, or \code{"bar"} for a bar plot. You may use initial letter only
 #'          for this argument.
-#' @param geom.colors A color palette for fillng the geoms. If not specified, the diverging \code{"RdBl"} color palette
-#'          from the color brewer palettes is used, resulting in red colors for negative and blue colors
-#'          for positive factor loadings, that become lighter the weaker the loadings are. Use any
-#'          color palette that is suitbale for the \code{scale_fill_gradientn} argument of ggplot2.
-#' @param geom.size Specifies the circle size factor. The circle size depends on the correlation
-#'          value multiplicated with this factor. Default is 10.
-#' @param breakTitleAt Wordwrap for diagram title. Determines how many chars of the title are displayed in
-#'          one line and when a line break is inserted into the title. Default is 50.
-#' @param breakLabelsAt Wordwrap for diagram labels. Determines how many chars of the category labels are displayed in 
-#'          one line and when a line break is inserted. Default is 12.
-#' @param showValueLabels Whether factor loading values should be plotted to each geom.
-#'          Default is \code{TRUE}.
-#' @param showCronbachsAlpha If \code{TRUE} (default), the cronbach's alpha value for each factor scale will be calculated,
-#'          i.e. all variables with the highest loading for a factor are taken for the
-#'          reliability test. The result is an alpha value for each factor dimension.
-#'          Only applies when \code{data} is a data frame and no \code{\link{prcomp}} object.
-#' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
-#'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
 #' @return (Invisibly) returns a \code{\link{structure}} with
 #'          \itemize{
 #'            \item the varimax-rotated factor loading matrix (\code{varim})
 #'            \item the column indices of removed variables (for more details see next list item) (\code{removed.colindex})
-#'            \item an updated data frame containing all factors that have a clear loading on a specific scale in case \code{data} was a data frame (See argument \code{factorLoadingTolerance} for more details) (\code{removed.df})
+#'            \item an updated data frame containing all factors that have a clear loading on a specific scale in case \code{data} was a data frame (See argument \code{fctr.load.tlrn} for more details) (\code{removed.df})
 #'            \item the \code{factor.index}, i.e. the column index of each variable with the highest factor loading for each factor,
 #'            \item the ggplot-object (\code{plot}),
 #'            \item the data frame that was used for setting up the ggplot-object (\code{df}).
 #'            }
 #' 
+#' @inheritParams sjp.grpfrq
+#' @inheritParams sjp.glmer
+#' @inheritParams sjt.pca
+#' 
 #' @note This PCA uses the \code{\link{prcomp}} function and the \code{\link{varimax}} rotation.
 #' 
 #' @examples
 #' # randomly create data frame with 7 items, each consisting of 4 categories
-#' likert_4 <- data.frame(sample(1:4, 
-#'                               500, 
-#'                               replace = TRUE, 
-#'                               prob = c(0.2, 0.3, 0.1, 0.4)),
-#'                        sample(1:4, 
-#'                               500, 
-#'                               replace = TRUE, 
-#'                               prob = c(0.5, 0.25, 0.15, 0.1)),
-#'                        sample(1:4, 
-#'                               500, 
-#'                               replace = TRUE, 
-#'                               prob = c(0.4, 0.15, 0.25, 0.2)),
-#'                        sample(1:4, 
-#'                               500, 
-#'                               replace = TRUE, 
-#'                               prob = c(0.25, 0.1, 0.4, 0.25)),
-#'                        sample(1:4, 
-#'                               500, 
-#'                               replace = TRUE, 
-#'                               prob = c(0.1, 0.4, 0.4, 0.1)),
-#'                        sample(1:4, 
-#'                               500, 
-#'                               replace = TRUE),
-#'                        sample(1:4, 
-#'                               500, 
-#'                               replace = TRUE, 
-#'                               prob = c(0.35, 0.25, 0.15, 0.25)))
+#' likert_4 <- data.frame(
+#'   sample(1:4, 500, replace = TRUE, prob = c(0.2, 0.3, 0.1, 0.4)),
+#'   sample(1:4, 500, replace = TRUE, prob = c(0.5, 0.25, 0.15, 0.1)),
+#'   sample(1:4, 500, replace = TRUE, prob = c(0.4, 0.15, 0.25, 0.2)),
+#'   sample(1:4, 500, replace = TRUE, prob = c(0.25, 0.1, 0.4, 0.25)),
+#'   sample(1:4, 500, replace = TRUE, prob = c(0.1, 0.4, 0.4, 0.1)),
+#'   sample(1:4, 500, replace = TRUE),
+#'   sample(1:4, 500, replace = TRUE, prob = c(0.35, 0.25, 0.15, 0.25))
+#' )
 #'
 #' # Create variable labels
 #' colnames(likert_4) <- c("V1", "V2", "V3", "V4", "V5", "V6", "V7")
@@ -104,17 +56,10 @@
 #' sjp.pca(likert_4, type = "bar")
 #' 
 #' # manually compute PCA
-#' pca <- prcomp(na.omit(likert_4), 
-#'               retx = TRUE, 
-#'               center = TRUE, 
-#'               scale. = TRUE)
+#' pca <- prcomp(na.omit(likert_4), retx = TRUE, center = TRUE, scale. = TRUE)
 #' # plot results from PCA as circles, including Eigenvalue-diagnostic.
 #' # note that this plot does not compute the Cronbach's Alpha
-#' sjp.pca(pca, 
-#'         plotEigenvalues = TRUE, 
-#'         type = "circle",
-#'         geom.size = 10)
-#' 
+#' sjp.pca(pca, plot.eigen = TRUE, type = "circle", geom.size = 10)
 #' 
 #' # -------------------------------
 #' # Data from the EUROFAMCARE sample dataset
@@ -149,42 +94,34 @@
 #' @importFrom stats na.omit prcomp
 #' @export
 sjp.pca <- function(data,
-                    numberOfFactors = NULL,
-                    factorLoadingTolerance = 0.1,
-                    plotEigenvalues = FALSE,
+                    nmbr.fctr = NULL,
+                    fctr.load.tlrn = 0.1,
+                    plot.eigen = FALSE,
                     digits = 2,
                     title = NULL,
-                    axisLabels.y = NULL,
-                    type = "b",
+                    axis.labels = NULL,
+                    type = c("bar", "circle", "tile"),
                     geom.size = .6,
                     geom.colors = "RdBu",
-                    breakTitleAt = 50,
-                    breakLabelsAt = 30,
-                    showValueLabels = TRUE,
-                    showCronbachsAlpha = TRUE,
-                    printPlot = TRUE) {
+                    wrap.title = 50,
+                    wrap.labels = 30,
+                    show.values = TRUE,
+                    show.cronb = TRUE,
+                    prnt.plot = TRUE) {
   # --------------------------------------------------------
   # check arguments
   # --------------------------------------------------------
-  if (type == "circles" || type == "circle") type <- "c"
-  if (type == "tiles" || type == "tile") type <- "t"
-  if (type == "bars" || type == "bar") type <- "b"
+  type <- match.arg(type)
   # --------------------------------------------------------
   # try to automatically set labels is not passed as argument
   # --------------------------------------------------------
-  if (is.null(axisLabels.y) && is.data.frame(data)) {
+  if (is.null(axis.labels) && is.data.frame(data)) {
     # if yes, iterate each variable
     for (i in 1:ncol(data)) {
-      # retrieve variable name attribute
-      vn <- sjmisc::get_label(data[[i]], def.value = colnames(data)[i])
+      # retrieve variable name attribute and
       # if variable has attribute, add to variableLabel list
-      if (!is.null(vn)) {
-        axisLabels.y <- c(axisLabels.y, vn)
-      } else {
-        # else break out of loop
-        axisLabels.y <- NULL
-        break
-      }
+      axis.labels <- c(axis.labels,
+                       sjmisc::get_label(data[[i]], def.value = colnames(data)[i]))
     }
   }
   # ----------------------------
@@ -199,21 +136,17 @@ sjp.pca <- function(data,
   # check if user has passed a data frame
   # or a pca object
   # ----------------------------
-  if (class(data) == "prcomp") {
+  if (any(class(data) == "prcomp")) {
     pcadata <- data
     dataframeparam <- FALSE
   } else {
     pcadata <- stats::prcomp(stats::na.omit(data), retx = TRUE, center = TRUE, scale. = TRUE)
     dataframeparam <- TRUE
   }
-  # --------------------------------------------------------
-  # unlist labels
-  # --------------------------------------------------------
-  if (!is.null(axisLabels.y) && is.list(axisLabels.y)) axisLabels.y <- unlistlabels(axisLabels.y)
   # ----------------------------
   # calculate eigenvalues
   # ----------------------------
-  pcadata.eigenval <- pcadata$sdev^2
+  pcadata.eigenval <- pcadata$sdev ^ 2
   # ----------------------------
   # retrieve best amount of factors according
   # to Kaiser-critearia, i.e. factors with eigen value > 1
@@ -222,7 +155,7 @@ sjp.pca <- function(data,
   # ----------------------------
   # plot eigenvalues
   # ----------------------------
-  if (plotEigenvalues) {
+  if (plot.eigen) {
     # create data frame with eigen values
     mydat <- as.data.frame(cbind(xpos = 1:length(pcadata.eigenval), eigen = pcadata.eigenval))
     # plot eigenvalues as line curve
@@ -232,12 +165,8 @@ sjp.pca <- function(data,
         geom_line() + geom_point() +
         geom_hline(yintercept = 1, linetype = 2, colour = "grey50") +
         # print best number of factors according to eigen value
-        annotate("text", 
-                 label = sprintf("Factors: %i", pcadata.kaiser), 
-                 x = Inf, 
-                 y = Inf, 
-                 vjust = "top", 
-                 hjust = "top") +
+        annotate("text", label = sprintf("Factors: %i", pcadata.kaiser), 
+                 x = Inf, y = Inf, vjust = "top", hjust = "top") +
         scale_x_continuous(breaks = c(seq(1, nrow(mydat), by = 2))) +
         labs(title = NULL, y = "Eigenvalue", x = "Number of factors")
     plot(eigenplot)
@@ -252,7 +181,7 @@ sjp.pca <- function(data,
   # varimax rotation, retrieve factor loadings
   # --------------------------------------------------------
   # check for predefined number of factors
-  if (!is.null(numberOfFactors) && is.numeric(numberOfFactors)) pcadata.kaiser <- numberOfFactors
+  if (!is.null(nmbr.fctr) && is.numeric(nmbr.fctr)) pcadata.kaiser <- nmbr.fctr
   pcadata.varim <- varimaxrota(pcadata, pcadata.kaiser)
   # pcadata.varim = varimax(loadings(pcadata))
   # create data frame with factor loadings
@@ -262,14 +191,14 @@ sjp.pca <- function(data,
   # check if user defined labels have been supplied
   # if not, use variable names from data frame
   # ----------------------------
-  if (is.null(axisLabels.y)) axisLabels.y <- row.names(df)
+  if (is.null(axis.labels)) axis.labels <- row.names(df)
   # ----------------------------
   # Prepare length of title and labels
   # ----------------------------
   # check length of diagram title and split longer string at into new lines
-  if (!is.null(title)) title <- sjmisc::word_wrap(title, breakTitleAt)
+  if (!is.null(title)) title <- sjmisc::word_wrap(title, wrap.title)
   # check length of x-axis-labels and split longer strings at into new lines
-  if (!is.null(axisLabels.y)) axisLabels.y <- sjmisc::word_wrap(axisLabels.y, breakLabelsAt)
+  if (!is.null(axis.labels)) axis.labels <- sjmisc::word_wrap(axis.labels, wrap.labels)
   # --------------------------------------------------------
   # this function checks which items have unclear factor loadings,
   # i.e. which items do not strongly load on a single factor but
@@ -288,7 +217,7 @@ sjp.pca <- function(data,
       # retrieve 2. highest loading
       max2load <- sort(rowval, TRUE)[2]
       # check difference between both
-      if (abs(maxload - max2load) < factorLoadingTolerance) {
+      if (abs(maxload - max2load) < fctr.load.tlrn) {
         # if difference is below the tolerance,
         # remeber row-ID so we can remove that items
         # for further PCA with updated data frame
@@ -342,7 +271,7 @@ sjp.pca <- function(data,
     alphaValues <- getCronbach(data, getItemLoadings(df))
   } else {
     message("Cronbach's Alpha can only be calculated when having a data frame with each component / variable as column.")
-    showCronbachsAlpha <- FALSE
+    show.cronb <- FALSE
   }
   # -------------------------------------
   # create list with factor loadings that indicate
@@ -353,41 +282,33 @@ sjp.pca <- function(data,
   # retrieve those items that have unclear factor loadings, i.e.
   # which almost load equally on several factors. The tolerance
   # that indicates which difference between factor loadings is
-  # considered as "equally" is defined via factorLoadingTolerance
+  # considered as "equally" is defined via fctr.load.tlrn
   removableItems <- getRemovableItems(df)
   # rename columns, so we have numbers on x axis
-  names(df) <- c(1:ncol(df))
+  names(df) <- 1:ncol(df)
   # convert to long data
-  df <- tidyr::gather(df, 
-                      "xpos", 
-                      "value", 
-                      1:ncol(df), 
-                      factor_key = TRUE)  
+  df <- tidyr::gather(df, "xpos", "value", 1:ncol(df), factor_key = TRUE)  
   # we need new columns for y-positions and point sizes
   df <- cbind(df, ypos = 1:nrow(pcadata.varim$loadings), psize = exp(abs(df$value)) * geom.size)
-  if (!showValueLabels) {
-    valueLabels <- c("")
+  if (!show.values) {
+    valueLabels <- ""
   } else {
     valueLabels <- sprintf("%.*f", digits, df$value)
   }
   # --------------------------------------------------------
   # start with base plot object here
   # --------------------------------------------------------
-  if (type == "b") {
-    heatmap <- ggplot(df, aes(x = rev(factor(ypos)), 
-                              y = abs(value), 
-                              fill = value))
+  if (type == "bar") {
+    heatmap <- ggplot(df, aes(x = rev(factor(ypos)), y = abs(value), fill = value))
   } else {
-    heatmap <- ggplot(data = df, aes(x = xpos, 
-                                     y = ypos, 
-                                     fill = value))
+    heatmap <- ggplot(data = df, aes(x = xpos, y = ypos, fill = value))
   }
   # --------------------------------------------------------
   # determine the geom type, either points when "type" is "circles"
   # --------------------------------------------------------
-  if (type == "c") {
+  if (type == "circle") {
     geo <- geom_point(shape = 21, size = df$psize)
-  } else if (type == "t") {
+  } else if (type == "tile") {
     # ----------------------------------------
     # or boxes / tiles when "type" is "tile"
     # ----------------------------------------
@@ -398,8 +319,7 @@ sjp.pca <- function(data,
     # ----------
     geo <- geom_bar(stat = "identity", width = geom.size)
   }
-  heatmap <- heatmap +
-    geo +
+  heatmap <- heatmap + geo +
     # --------------------------------------------------------
     # fill gradient colour from distinct color brewer palette. 
     # negative correlations are dark red, positive corr. are dark blue, 
@@ -412,26 +332,23 @@ sjp.pca <- function(data,
   # --------------------------------------------------------
   # facet bars, and flip coordinates
   # --------------------------------------------------------
-  if (type == "b") {
+  if (type == "bar") {
     heatmap <- heatmap + 
-      scale_x_discrete(labels = rev(axisLabels.y)) +
+      scale_x_discrete(labels = rev(axis.labels)) +
       scale_y_continuous(limits = c(0, 1), breaks = seq(0, 1, .2)) +
       facet_grid(~xpos) +
       coord_flip()
   } else {
     heatmap <- heatmap + 
       geom_text(label = valueLabels) +
-      scale_y_reverse(breaks = seq(1, length(axisLabels.y), by = 1), 
-                      labels = axisLabels.y)
+      scale_y_reverse(breaks = seq(1, length(axis.labels), by = 1), 
+                      labels = axis.labels)
     # --------------------------------------------------------
     # show cronbach's alpha value for each scale 
     # --------------------------------------------------------
-    if (showCronbachsAlpha) {
+    if (show.cronb) {
       heatmap <- heatmap +
-        annotate("text", 
-                 x = alphaValues$nr, 
-                 y = Inf, 
-                 parse = TRUE, 
+        annotate("text", x = alphaValues$nr, y = Inf, parse = TRUE, 
                  label = sprintf("alpha == %.*f", digits, alphaValues$alpha), 
                  vjust = -0.5)
     }
@@ -439,16 +356,16 @@ sjp.pca <- function(data,
   # --------------------------------------------------------
   # print plot
   # --------------------------------------------------------
-  if (printPlot) graphics::plot(heatmap)
+  if (prnt.plot) graphics::plot(heatmap)
   # --------------------------------------------------------
   # if we have a data frame, all factors which do not clearly
-  # load on a specific dimension (see patameter "factorLoadingTolerance")
+  # load on a specific dimension (see patameter "fctr.load.tlrn")
   # will be removed and the updated data frame will be returned.
   # the user may calculate another PCA with the updated data frame
   # in order to get more clearly factor loadings
   # --------------------------------------------------------
   remdf <- NULL
-  if (class(data) == "data.frame") {
+  if (any(class(data) == "data.frame")) {
     message("Following items have no clear factor loading:")
     if (!is.null(removableItems)) {
       message(colnames(data)[removableItems])
