@@ -24,27 +24,13 @@
 #'          When \code{x} is not a vector, but a fitted model object, the function
 #'          is detected automatically. If \code{x} is a vector, \code{fun} defaults
 #'          to \code{"lm"}.
-#' @param axisTitle.x A label for the x axis. Use \code{NULL} to automatically detect 
-#'          variable names that will be used as title (see \code{\link[sjmisc]{set_label}}) for details).
-#' @param axisTitle.y A label for the y axis. Use \code{NULL} to automatically detect 
-#'          variable names that will be used as title (see \code{\link[sjmisc]{set_label}}) for details).
-#' @param showScatterPlot If \code{TRUE} (default), a scatter plot of response and predictor values
-#'          for each predictor of the fitted model \code{fit} is plotted.
-#'          Only applies if \code{type = "lm"} and fitted model has only one predictor,
-#'          or if \code{type = "pred"} or \code{type = "resid"}.
-#' @param showLoess If \code{TRUE}, an additional loess-smoothed line is plotted.
-#' @param showLoessCI If \code{TRUE}, a confidence region for the loess-smoothed line
+#' @param show.loess If \code{TRUE}, an additional loess-smoothed line is plotted.
+#' @param show.loess.ci If \code{TRUE}, a confidence region for the loess-smoothed line
 #'          will be plotted.
-#' @param showPValues logical, if \code{TRUE} (default), p-values for polynomial terms are
+#' @param show.p logical, if \code{TRUE} (default), p-values for polynomial terms are
 #'          printed to the console.
-#' @param geom.colors User defined color palette for geoms. Must either be vector with two color values
-#'          or a specific color palette code. See 'Note' in \code{\link{sjp.grpfrq}}.
-#' @param geom.size size resp. width of plotted lines.
-#' @param loessLineColor color of the loess-smoothed line. Only applies, if \code{showLoess = TRUE}.
-#' @param pointColor color of the scatter plot's point. Only applies, if \code{showScatterPlot = TRUE}.
-#' @param pointAlpha The alpha values of the scatter plot's point-geoms. Default is 0.2.
-#' @param printPlot If \code{TRUE} (default), plots the results as graph. Use \code{FALSE} if you don't
-#'          want to plot any graphs. In either case, the ggplot-object will be returned as value.
+#' @param loessLineColor color of the loess-smoothed line. Only applies, if \code{show.loess = TRUE}.
+#' @param point.color color of the scatter plot's point. Only applies, if \code{scatter.plot = TRUE}.
 #' @return (insisibily) returns 
 #'           \describe{
 #'            \item{\code{plot}}{the ggplot-object with the complete plot}
@@ -52,6 +38,9 @@
 #'            \item{\code{cutpoints}}{a data frame that indicates x-values and predicted y-values of each direction change in the loess curvature}
 #'           }
 #' 
+#' @inheritParams sjp.glmer
+#' @inheritParams sjp.lm
+#' 
 #' @details For each polynomial degree, a simple linear regression on \code{x} (resp.
 #'            the extracted response, if \code{x} is a fitted model) is performed,
 #'            where only the polynomial term \code{poly.term} is included as independent variable.
@@ -64,7 +53,7 @@
 #'            Polynomials are computed using the \code{\link{poly}} function,
 #'            with argument \code{raw = TRUE}. \cr \cr
 #'            To find out which polynomial degree fits best to the data, a loess-smoothed
-#'            line (in dark grey) can be added (with \code{showLoess = TRUE}). The polynomial curves
+#'            line (in dark grey) can be added (with \code{show.loess = TRUE}). The polynomial curves
 #'            that comes closest to the loess-smoothed line should be the best
 #'            fit to the data.
 #'   
@@ -82,27 +71,23 @@
 #' sjp.poly(efc$c160age, efc$quol_5, 2)
 #' 
 #' # linear to cubic fit
-#' sjp.poly(efc$c160age, efc$quol_5, 
-#'          1:4, showScatterPlot = FALSE)
-#' 
+#' sjp.poly(efc$c160age, efc$quol_5, 1:4, scatter.plot = FALSE)
 #' 
 #' library(sjmisc)
 #' data(efc)
 #' # fit sample model
 #' fit <- lm(tot_sc_e ~ c12hour + e17age + e42dep, data = efc)
 #' # inspect relationship between predictors and response
-#' sjp.lm(fit, type = "pred", 
-#'        showLoess = TRUE, showScatterPlot = FALSE)
+#' sjp.lm(fit, type = "slope", show.loess = TRUE, scatter.plot = FALSE)
 #' # "e17age" does not seem to be linear correlated to response
 #' # try to find appropiate polynomial. Grey line (loess smoothed)
 #' # indicates best fit. Looks like x^4 has the best fit,
 #' # however, only x^3 has significant p-values.
-#' sjp.poly(fit, "e17age", 2:4, showScatterPlot = FALSE)
+#' sjp.poly(fit, "e17age", 2:4, scatter.plot = FALSE)
 #' 
 #' \dontrun{
 #' # fit new model
-#' fit <- lm(tot_sc_e ~ c12hour + e42dep +
-#'           e17age + I(e17age^2) + I(e17age^3),
+#' fit <- lm(tot_sc_e ~ c12hour + e42dep + e17age + I(e17age^2) + I(e17age^3),
 #'           data = efc)
 #' # plot marginal effects of polynomial term
 #' sjp.lm(fit, type = "poly", poly.term = "e17age")}
@@ -116,18 +101,17 @@ sjp.poly <- function(x,
                      poly.degree,
                      poly.scale = FALSE,
                      fun = NULL,
-                     axisTitle.x = NULL,
-                     axisTitle.y = NULL,
-                     showScatterPlot = TRUE,
-                     showLoess = TRUE,
-                     showLoessCI = TRUE,
-                     showPValues = TRUE,
+                     axis.title = NULL,
+                     scatter.plot = TRUE,
+                     show.loess = TRUE,
+                     show.loess.ci = TRUE,
+                     show.p = TRUE,
                      geom.colors = NULL,
                      geom.size = .8,
                      loessLineColor = "#808080",
-                     pointColor = "#404040",
-                     pointAlpha = .2,
-                     printPlot = TRUE) {
+                     point.color = "#404040",
+                     point.alpha = .2,
+                     prnt.plot = TRUE) {
   # --------------------------------------------
   # check color parameter
   # --------------------------------------------
@@ -142,19 +126,22 @@ sjp.poly <- function(x,
   # --------------------------------------------
   # parameter check: fitted model or variables?
   # --------------------------------------------
-  if ((any(class(x) == "glmerMod") || any(class(x) == "lmerMod" || any(class(x) == "merModLmerTest"))) && !requireNamespace("lme4", quietly = TRUE)) {
-    stop("Package 'lme4' needed for this function to work. Please install it.", call. = FALSE)
-  }
-  if (any(class(x) == "glmerMod") || any(class(x) == "lmerMod") || any(class(x) == "merModLmerTest")) {
+  if (is_merMod(x)) { 
+    if (!requireNamespace("lme4", quietly = TRUE))
+      stop("Package `lme4`` needed for this function to work. Please install it.", call. = FALSE)
     # retrieve response vector
     resp <- lme4::getME(x, "y")
+    # get model frame
+    mf <- stats::model.frame(x)
     # retrieve polynomial term
-    poly.term <- x@frame[[which(colnames(x@frame) == poly.term)]]
+    poly.term <- mf[[poly.term]]
   } else if (any(class(x) == "lm") || any(class(x) == "glm")) {
+    # get model frame
+    mf <- stats::model.frame(x)
     # retrieve response vector
-    resp <- x$model[[1]]
+    resp <- mf[[1]]
     # retrieve polynomial term
-    poly.term <- x$model[[which(colnames(x$model) == poly.term)]]
+    poly.term <- mf[[poly.term]]
   } else {
     resp <- x
   }
@@ -171,13 +158,8 @@ sjp.poly <- function(x,
   # --------------------------------------------
   # retrieve labels
   # --------------------------------------------
-  if (is.null(axisTitle.x))
-    axisTitle.x <- sjmisc::get_label(poly.term, def.value = defv)
-  if (is.null(axisTitle.y)) 
-    axisTitle.y <- sjmisc::get_label(resp, def.value = "Response")
-  # no labels found? set default then
-  if (is.null(axisTitle.x)) axisTitle.x <- "Polynomial term"
-  if (is.null(axisTitle.y)) axisTitle.y <- "Response"
+  if (is.null(axis.title)) axis.title <- sjmisc::get_label(poly.term, def.value = defv)
+  axisTitle.y <- sjmisc::get_label(resp, def.value = "Response")
   # --------------------------------------------
   # init data frame
   # --------------------------------------------
@@ -194,13 +176,12 @@ sjp.poly <- function(x,
   # --------------------------------------------
   for (i in poly.degree) {
     # poly-function can't cope with missings, so remove them here
-    mydat <- na.omit(data.frame(x = poly.term, y = resp))
+    mydat <- stats::na.omit(data.frame(x = poly.term, y = resp))
     # fit model with polynomials
     if (fun == "lm")
       fit <- stats::lm(mydat$y ~ poly(mydat$x, i, raw = TRUE))
     else
-      fit <- stats::glm(mydat$y ~ poly(mydat$x, i, raw = TRUE), 
-                        family = stats::binomial(link = "logit"))
+      fit <- stats::glm(mydat$y ~ poly(mydat$x, i, raw = TRUE), family = stats::family(x))
     # check whether we have an integer poly.degree
     # or a float value
     poly.digit <- ifelse(i %% 1 == 0, 0, 1)
@@ -209,7 +190,7 @@ sjp.poly <- function(x,
                                     stats::predict(fit), 
                                     sprintf("x^%.*f", poly.digit, i)))
     # print p-values?
-    if (showPValues) {
+    if (show.p) {
       # get p-values
       pvals <- summary(fit)$coefficients[-1, 4]
       # prepare output string
@@ -227,22 +208,22 @@ sjp.poly <- function(x,
   # create plot
   polyplot <- ggplot(plot.df, aes(x, y, colour = grp))
   # show scatter plot as well?
-  if (showScatterPlot) polyplot <- polyplot + geom_jitter(colour = pointColor, alpha = pointAlpha)
+  if (scatter.plot) polyplot <- polyplot + geom_jitter(colour = point.color, alpha = point.alpha)
   # show loess curve? this curve indicates the "perfect" curve through
   # the data
-  if (showLoess) polyplot <- polyplot + stat_smooth(method = "loess", 
+  if (show.loess) polyplot <- polyplot + stat_smooth(method = "loess", 
                                                     color = loessLineColor,
-                                                    se = showLoessCI,
+                                                    se = show.loess.ci,
                                                     size = geom.size)
   # add curves for polynomials
   polyplot <- polyplot + 
     geom_line(aes(y = pred), size = geom.size) + 
     scale_color_manual(values = geom.colors, labels = lapply(poly.degree, function(j) bquote(x^.(j)))) +
-    labs(x = axisTitle.x, y = axisTitle.y, colour = "Polynomial\ndegrees")
+    labs(x = axis.title, y = axisTitle.y, colour = "Polynomial\ndegrees")
   # ---------------------------------------------------------
   # Check whether ggplot object should be returned or plotted
   # ---------------------------------------------------------
-  if (printPlot) print(polyplot)
+  if (prnt.plot) print(polyplot)
   # -------------------------------------
   # return results
   # -------------------------------------
