@@ -15,58 +15,42 @@
 #'          dots along the y axis.
 #' @param grp grouping variable. If not \code{NULL}, the scatter plot will be grouped. See
 #'          'Examples'. Default is \code{NULL}, i.e. not grouping is done.
-#' @param pointLabels character vector with names for each coordinate pair given
+#' @param dot.labels character vector with names for each coordinate pair given
 #'          by \code{x} and \code{y}, so text labels are added to the plot. 
 #'          Must be of same length as \code{x} and \code{y}.
-#'          If \code{pointLabels} has a different length, data points will be trimmed
-#'          to match \code{pointLabels}. If \code{pointLabels = NULL} (default),
+#'          If \code{dot.labels} has a different length, data points will be trimmed
+#'          to match \code{dot.labels}. If \code{dot.labels = NULL} (default),
 #'          no labels are printed.
-#' @param label.size Size of text labels if argument \code{pointLabels} is used.
-#' @param axisTitle.x title for the x axis. Use \code{NULL} to automatically
-#'          detect variable names that will be used as title
-#'          (see \code{\link[sjmisc]{set_label}}) for details).
-#' @param axisTitle.y title for the y axis.
-#'          Use \code{NULL} to automatically detect variable names that will be used as title
-#'          (see \code{\link[sjmisc]{set_label}}) for details).
-#' @param geom.size size of point geoms.
-#' @param geom.colors color(s) of point geoms. If \code{grp} is not \code{NULL},
-#'          groups are indicated by different colors, thus a vector with multiple
-#'          color values has to be supplied.
-#' @param showTickMarkLabels.x logica, whether x axis tick mark labels should be shown or not.
-#' @param showTickMarkLabels.y logical, hether y axis tick mark labels  should be shown or not.
-#' @param showGroupFitLine logical, if \code{TRUE}, a fitted line for each group
+#' @param label.size Size of text labels if argument \code{dot.labels} is used.
+#' @param fit.line.grps logical, if \code{TRUE}, a fitted line for each group
 #'          is drawn. See \code{fitmethod} to change the fit method of the fitted lines.
-#' @param showTotalFitLine logical, if \code{TRUE}, a fitted line for the overall
+#' @param fit.line logical, if \code{TRUE}, a fitted line for the overall
 #'          scatterplot is drawn. See \code{fitmethod} to change the fit method
 #'          of the fitted line.
-#' @param show.ci logical, if \code{TRUE}, a shaded region indicating the
-#'          confidence interval of the fitted lines will be added.
 #' @param fitmethod By default, a linear method (\code{"lm"}) is used for fitting
 #'          the fit lines. Possible values are for instance \code{"lm"}, \code{"glm"},
 #'          \code{"loess"} or \code{"auto"}.
-#' @param useJitter logical, if \code{TRUE}, points will be jittered (to avoid overplotting).
-#' @param useCount logical, if \code{TRUE}, overlapping points at same coordinates
+#' @param jitter.dots logical, if \code{TRUE}, points will be jittered (to avoid overplotting).
+#' @param emph.dots logical, if \code{TRUE}, overlapping points at same coordinates
 #'          will be becomme larger, so point size indicates amount of overlapping.
-#' @param autojitter logical, if \code{TRUE}, points will be jittered according
+#' @param auto.jitter logical, if \code{TRUE}, points will be jittered according
 #'          to an overlap-estimation. A matrix of \code{x} and \code{y} values
 #'          is created and the amount of cells (indicating a unique point position)
-#'          is calculated. If more than 15\% (see \code{jitterRatio}) of the
+#'          is calculated. If more than 15\% (see \code{jitter.ratio}) of the
 #'          approximated amount of unique point coordinates seem to
 #'          overlap, they are automatically jittered.
-#' @param jitterRatio ratio of tolerated overlapping (see \code{autojitter}).
+#' @param jitter.ratio ratio of tolerated overlapping (see \code{auto.jitter}).
 #'          If approximated amount of overlapping  points exceed this ratio,
 #'          they are automatically jittered. Default is 0.15. Valid values range
 #'          between 0 and 1.
-#' @param showRug logical, if \code{TRUE}, a marginal rug plot is displayed
+#' @param show.rug logical, if \code{TRUE}, a marginal rug plot is displayed
 #'          in the graph.
-#' @param facet.grid \code{TRUE} when each scatter plot group should be plotted as single facet instead of
-#'          an integrated single graph. Only applies if \code{grp} is not \code{NULL}. Each category of
-#'          \code{grp} will be plotted in an own facet.
 #'
 #' @return (Insisibily) returns the ggplot-object with the complete plot (\code{plot}) as well as the data frame that
 #'           was used for setting up the ggplot-object (\code{df}).
 #'
 #' @inheritParams sjp.grpfrq
+#' @inheritParams sjp.lm
 #'
 #' @examples
 #' # load sample date
@@ -83,38 +67,33 @@
 #' sjp.scatter(efc$c160age, efc$e17age, efc$e42dep)
 #'
 #' # grouped and jittered scatter plot with marginal rug plot
-#' sjp.scatter(efc$e16sex,efc$neg_c_7, efc$c172code, showRug = TRUE)
+#' sjp.scatter(efc$e16sex,efc$neg_c_7, efc$c172code, show.rug = TRUE)
 #'
 #' # grouped and labelled scatter plot, not using the auto-detection
 #' # of labels, but instead pass labels as arguments
 #' sjp.scatter(efc$c160age, efc$e17age, efc$e42dep,
-#'             title = "Scatter Plot",
-#'             legendTitle = get_label(efc)['e42dep'],
-#'             legendLabels = get_labels(efc)[['e42dep']],
-#'             axisTitle.x = get_label(efc)['c160age'],
-#'             axisTitle.y = get_label(efc)['e17age'],
-#'             showGroupFitLine = TRUE)
+#'             title = "Scatter Plot", legend.title = get_label(efc)['e42dep'],
+#'             legend.labels = get_labels(efc)[['e42dep']],
+#'             axis.titles = c(get_label(efc)['c160age'], get_label(efc)['e17age']),
+#'             fit.line.grps = TRUE)
 #'
 #' # grouped and labelled scatter plot as facets
-#' sjp.scatter(efc$c160age,efc$e17age, efc$e42dep,
-#'             showGroupFitLine = TRUE,
-#'             facet.grid = TRUE,
-#'             show.ci = TRUE)
+#' sjp.scatter(efc$c160age,efc$e17age, efc$e42dep, fit.line.grps = TRUE,
+#'             facet.grid = TRUE, show.ci = TRUE)
 #'
 #' # plot residuals of fitted models
 #' fit <- lm(neg_c_7 ~ quol_5, data = efc)
-#' sjp.scatter(y = fit$residuals, showTotalFitLine = TRUE)
+#' sjp.scatter(y = fit$residuals, fit.line = TRUE)
 #'
 #' # "hide" axis titles
-#' sjp.scatter(efc$c160age, efc$e17age, efc$e42dep,
-#'             title = "", axisTitle.x = "", axisTitle.y = "")
+#' sjp.scatter(efc$c160age, efc$e17age, efc$e42dep, title = "", 
+#'             axis.titles = c("", ""))
 #'
 #' # plot text labels
 #' pl <- c(1:10)
-#' for (i in 1:10) pl[i] <- paste(sample(c(0:9, letters, LETTERS),
-#'                                       8, replace = TRUE),
-#'                                collapse = "")
-#' sjp.scatter(runif(10), runif(10), pointLabels = pl)
+#' for (i in 1:10) 
+#'   pl[i] <- paste(sample(c(0:9, letters, LETTERS), 8, replace = TRUE), collapse = "")
+#' sjp.scatter(runif(10), runif(10), dot.labels = pl)
 #'
 #' @importFrom scales brewer_pal
 #' @importFrom stats na.omit
@@ -124,38 +103,35 @@ sjp.scatter <- function(x = NULL,
                         y = NULL,
                         grp = NULL,
                         title = "",
-                        legendTitle = NULL,
-                        legendLabels = NULL,
-                        pointLabels = NULL,
-                        axisTitle.x = NULL,
-                        axisTitle.y = NULL,
-                        breakTitleAt = 50,
-                        breakLegendTitleAt = 20,
-                        breakLegendLabelsAt = 20,
+                        legend.title = NULL,
+                        legend.labels = NULL,
+                        dot.labels = NULL,
+                        axis.titles = NULL,
+                        wrap.title = 50,
+                        wrap.legend.title = 20,
+                        wrap.legend.labels = 20,
                         geom.size = 2,
                         label.size = 3,
                         geom.colors = NULL,
-                        showTickMarkLabels.x = TRUE,
-                        showTickMarkLabels.y = TRUE,
-                        showGroupFitLine = FALSE,
-                        showTotalFitLine = FALSE,
+                        show.axis.values = TRUE,
+                        fit.line.grps = FALSE,
+                        fit.line = FALSE,
                         show.ci = FALSE,
                         fitmethod = "lm",
-                        useJitter = FALSE,
-                        useCount = FALSE,
-                        autojitter = TRUE,
-                        jitterRatio = 0.15,
-                        showRug = FALSE,
-                        hideLegend = FALSE,
+                        jitter.dots = FALSE,
+                        emph.dots = FALSE,
+                        auto.jitter = TRUE,
+                        jitter.ratio = 0.15,
+                        show.rug = FALSE,
+                        show.legend = TRUE,
                         facet.grid = FALSE,
-                        printPlot = TRUE) {
+                        prnt.plot = TRUE) {
   # ------------------------
   # check if suggested packages are available
   # ------------------------
-  if (!is.null(pointLabels) && !requireNamespace("ggrepel", quietly = TRUE)) {
+  if (!is.null(dot.labels) && !requireNamespace("ggrepel", quietly = TRUE)) {
     stop("Package `ggrepel` needed to plot labels. Please install it.", call. = FALSE)
   }
-  
   # --------------------------------------------------------
   # get variable name
   # --------------------------------------------------------
@@ -163,27 +139,45 @@ sjp.scatter <- function(x = NULL,
   name.y <- get_var_name(deparse(substitute(y)))
   name.grp <- get_var_name(deparse(substitute(grp)))
   # --------------------------------------------------------
+  # any missing names?
+  # --------------------------------------------------------
+  if (is.null(name.x) || name.x == "NULL") name.x <- ""
+  if (is.null(name.y) || name.y == "NULL") name.y <- ""
+  # --------------------------------------------------------
+  # copy titles
+  # --------------------------------------------------------
+  if (is.null(axis.titles)) {
+    axisTitle.x <- NULL
+    axisTitle.y <- NULL
+  } else {
+    axisTitle.x <- axis.titles[1]
+    if (length(axis.titles) > 1) 
+      axisTitle.y <- axis.titles[2]#
+    else
+      axisTitle.y <- NULL
+  }
+  # --------------------------------------------------------
   # check parameters
   # --------------------------------------------------------
   if (is.null(x) && is.null(y)) {
     stop("At least either 'x' or 'y' must be specified.", call. = FALSE)
   }
-  if (useJitter && useCount) {
-    warning("Only one of `useJitter` and `useCount` may be `TRUE`. Defaulting `useJitter` to `FALSE`.")
-    useJitter <- FALSE
+  if (jitter.dots && emph.dots) {
+    warning("Only one of `jitter.dots` and `emph.dots` may be `TRUE`. Defaulting `jitter.dots` to `FALSE`.")
+    jitter.dots <- FALSE
   }
   if (is.null(x)) x <- c(1:length(y))
   if (is.null(y)) y <- c(1:length(x))
   # disable auto-jitter?
-  if (useCount) autojitter <- FALSE
+  if (emph.dots) auto.jitter <- FALSE
   # --------------------------------------------------------
   # try to automatically set labels is not passed as parameter
   # --------------------------------------------------------
-  if (is.null(legendLabels) && !is.null(grp)) legendLabels <- sjmisc::get_labels(grp,
-                                                                                 attr.only = F,
-                                                                                 include.values = NULL,
-                                                                                 include.non.labelled = T)
-  if (is.null(legendTitle) && !is.null(grp)) legendTitle <- sjmisc::get_label(grp, def.value = name.grp)
+  if (is.null(legend.labels) && !is.null(grp)) {
+    legend.labels <- sjmisc::get_labels(grp, attr.only = F, include.values = NULL,
+                                        include.non.labelled = T)
+  }
+  if (is.null(legend.title) && !is.null(grp)) legend.title <- sjmisc::get_label(grp, def.value = name.grp)
   if (is.null(axisTitle.x)) axisTitle.x <- sjmisc::get_label(x, def.value = name.x)
   if (is.null(axisTitle.y)) axisTitle.y <- sjmisc::get_label(y, def.value = name.y)
   if (is.null(title)) {
@@ -200,27 +194,27 @@ sjp.scatter <- function(x = NULL,
   # --------------------------------------------------------
   # remove titles if empty
   # --------------------------------------------------------
-  if (!is.null(legendTitle) && legendTitle == "") legendTitle <- NULL
+  if (!is.null(legend.title) && legend.title == "") legend.title <- NULL
   if (!is.null(axisTitle.x) && axisTitle.x == "") axisTitle.x <- NULL
   if (!is.null(axisTitle.y) && axisTitle.y == "") axisTitle.y <- NULL
   if (!is.null(title) && title == "") title <- NULL
   # ------------------------------------------
   # check for auto-jittering
   # ------------------------------------------
-  if (autojitter && !useJitter) {
+  if (auto.jitter && !jitter.dots) {
     # check for valid range of jitter ratio
-    if (jitterRatio <= 0 || jitterRatio >= 1) {
+    if (jitter.ratio <= 0 || jitter.ratio >= 1) {
       # inform user
-      warning("`jitterRatio` out of valid bounds. Using 0.15 for `jitterRatio`...")
-      jitterRatio <- 0.15
+      warning("`jitter.ratio` out of valid bounds. Using 0.15 for `jitter.ratio`...")
+      jitter.ratio <- 0.15
     }
     # retrieve the highest amount of points lying
     # on the same coordinate
     overlap <- nrow(table(x, y)) * ncol(table(x, y))
     # check ratio of overlapping points according to total points
-    if (overlap < (length(x) * jitterRatio)) {
+    if (overlap < (length(x) * jitter.ratio)) {
       # use jittering now
-      useJitter <- TRUE
+      jitter.dots <- TRUE
       message("auto-jittering values...")
     }
   }
@@ -232,49 +226,49 @@ sjp.scatter <- function(x = NULL,
     # if not, add a dummy grouping variable
     grp <- rep(1, length(x))
     # we don't need legend here
-    hideLegend <- TRUE
+    show.legend <- FALSE
   }
   # simple data frame
   df <- stats::na.omit(data.frame(cbind(x = x, y = y, grp = grp)))
   # group as factor
   df$grp <- as.factor(df$grp)
   # do we have point labels?
-  if (!is.null(pointLabels)) {
+  if (!is.null(dot.labels)) {
     # check length
-    if (length(pointLabels) > nrow(df)) {
+    if (length(dot.labels) > nrow(df)) {
       # Tell user that we have too many point labels
       warning("More point labels than data points. Omitting remaining point labels", call. = F)
       # shorten vector
-      pointLabels <- pointLabels[1:nrow(df)]
-    } else if (length(pointLabels) < nrow(df)) {
+      dot.labels <- dot.labels[1:nrow(df)]
+    } else if (length(dot.labels) < nrow(df)) {
       # Tell user that we have too less point labels
       warning("Less point labels than data points. Omitting remaining data point", call. = F)
       # shorten data frame
-      df <- df[1:length(pointLabels), ]
+      df <- df[1:length(dot.labels), ]
     }
     # append labels
-    df$pointLabels <- as.character(pointLabels)
+    df$dot.labels <- as.character(dot.labels)
   }
   # --------------------------------------------------------
   # Prepare and trim legend labels to appropriate size
   # --------------------------------------------------------
   # Check whether we have any labels passed as parameter
   # if not, use category text of group variable as legend text
-  if (is.null(legendLabels)) legendLabels <- c(sort(unique(df$grp)))
+  if (is.null(legend.labels)) legend.labels <- c(sort(unique(df$grp)))
   # wrap legend text lines
-  legendLabels <- sjmisc::word_wrap(legendLabels, breakLegendLabelsAt)
+  legend.labels <- sjmisc::word_wrap(legend.labels, wrap.legend.labels)
   # check whether we have a title for the legend
   # if yes, wrap legend title line
-  if (!is.null(legendTitle)) legendTitle <- sjmisc::word_wrap(legendTitle, breakLegendTitleAt)
+  if (!is.null(legend.title)) legend.title <- sjmisc::word_wrap(legend.title, wrap.legend.title)
   # check length of diagram title and split longer string at into new lines
   # every 50 chars
-  if (!is.null(title)) title <- sjmisc::word_wrap(title, breakTitleAt)
+  if (!is.null(title)) title <- sjmisc::word_wrap(title, wrap.title)
   # check length of x-axis title and split longer string at into new lines
   # every 50 chars
-  if (!is.null(axisTitle.x)) axisTitle.x <- sjmisc::word_wrap(axisTitle.x, breakTitleAt)
+  if (!is.null(axisTitle.x)) axisTitle.x <- sjmisc::word_wrap(axisTitle.x, wrap.title)
   # check length of x-axis title and split longer string at into new lines
   # every 50 chars
-  if (!is.null(axisTitle.y)) axisTitle.y <- sjmisc::word_wrap(axisTitle.y, breakTitleAt)
+  if (!is.null(axisTitle.y)) axisTitle.y <- sjmisc::word_wrap(axisTitle.y, wrap.title)
   # --------------------------------------------------------
   # Plot scatter plot
   # --------------------------------------------------------
@@ -282,8 +276,8 @@ sjp.scatter <- function(x = NULL,
   # --------------------------------------------------------
   # Add marginal rug
   # --------------------------------------------------------
-  if (showRug) {
-    if (useJitter) {
+  if (show.rug) {
+    if (jitter.dots) {
       scatter <- scatter + geom_rug(position = "jitter")
     } else {
       scatter <- scatter + geom_rug()
@@ -292,16 +286,16 @@ sjp.scatter <- function(x = NULL,
   # --------------------------------------------------------
   # Use Jitter/Points
   # --------------------------------------------------------
-  if (useJitter) {
+  if (jitter.dots) {
     # else plot dots
     scatter <- scatter + geom_jitter(size = geom.size)
     # do we have text?
-    if (!is.null(pointLabels))
-      scatter <- scatter + ggrepel::geom_text_repel(aes(label = pointLabels),
-                                           size = label.size,
-                                           position = "jitter")
+    if (!is.null(dot.labels))
+      scatter <- scatter + 
+        ggrepel::geom_text_repel(aes(label = dot.labels), size = label.size,
+                                 position = "jitter")
   } else {
-    if (useCount) {
+    if (emph.dots) {
       # indicate overlapping dots by point size
       scatter <- scatter + geom_count(show.legend = F)
     } else {
@@ -309,36 +303,30 @@ sjp.scatter <- function(x = NULL,
       scatter <- scatter + geom_point(size = geom.size)
     }
     # do we have text?
-    if (!is.null(pointLabels)) {
+    if (!is.null(dot.labels)) {
       scatter <- scatter + 
-        ggrepel::geom_text_repel(aes(label = pointLabels),
-                                 size = label.size)
+        ggrepel::geom_text_repel(aes(label = dot.labels), size = label.size)
       
     }
   }
   # --------------------------------------------------------
   # Show fitted lines
   # --------------------------------------------------------
-  if (showGroupFitLine) scatter <- scatter + stat_smooth(data = df,
-                                                         aes(colour = grp),
-                                                         method = fitmethod,
-                                                         se = show.ci)
-  if (showTotalFitLine) scatter <- scatter + stat_smooth(method = fitmethod,
-                                                         se = show.ci,
-                                                         colour = "black")
+  if (fit.line.grps) scatter <- scatter + 
+    stat_smooth(data = df, aes(colour = grp), method = fitmethod, se = show.ci)
+  if (fit.line) scatter <- scatter + 
+    stat_smooth(method = fitmethod, se = show.ci, colour = "black")
   # --------------------------------------------------------
   # set font size for axes.
   # --------------------------------------------------------
   scatter <- scatter +
-    labs(title = title,
-         x = axisTitle.x,
-         y = axisTitle.y,
-         colour = legendTitle)
+    labs(title = title, x = axisTitle.x, y = axisTitle.y, colour = legend.title)
   # --------------------------------------------------------
   # Hide or show tick marks
   # --------------------------------------------------------
-  if (!showTickMarkLabels.x) scatter <- scatter + scale_x_continuous(labels = NULL)
-  if (!showTickMarkLabels.y) scatter <- scatter + scale_y_continuous(labels = NULL)
+  if (!show.axis.values) 
+    scatter <- scatter + scale_y_continuous(labels = NULL) +
+                         scale_x_continuous(labels = NULL)
   # --------------------------------------
   # facet plot
   # --------------------------------------
@@ -359,13 +347,13 @@ sjp.scatter <- function(x = NULL,
   # ---------------------------------------------------------
   scatter <- sj.setGeomColors(scatter,
                               geom.colors,
-                              length(legendLabels),
-                              ifelse(isTRUE(hideLegend), FALSE, TRUE),
-                              legendLabels)
+                              length(legend.labels),
+                              show.legend,
+                              legend.labels)
   # ---------------------------------------------------------
   # Check whether ggplot object should be returned or plotted
   # ---------------------------------------------------------
-  if (printPlot) graphics::plot(scatter)
+  if (prnt.plot) graphics::plot(scatter)
   # -------------------------------------
   # return results
   # -------------------------------------
