@@ -13,84 +13,57 @@
 #' @param file destination file, if the output should be saved as file.
 #'          If \code{NULL} (default), the output will be saved as temporary file and 
 #'          openend either in the IDE's viewer pane or the default web browser.
-#' @param weightBy weight factor that will be applied to weight all cases from \code{data}.
-#'          Must be a vector of same length as \code{nrow(data)}. Default is \code{NULL}, so no weights are used.
-#' @param weightByTitleString suffix (as string) for the tabel caption, if \code{weightBy} is specified,
-#'          e.g. \code{weightByTitleString=" (weighted)"}. Default is \code{NULL}, so
-#'          the table caption will not have a suffix when cases are weighted.
-#' @param variableLabels character vector or a list of character vectors that indicate
-#'          the variable names of \code{data} and will be used as variable labels
-#'          in the output. Note that if multiple variables
-#'          are supplied (if \code{data} is a \code{\link{data.frame}}), the variable 
-#'          labels must be supplied as \code{list} object (see 'Examples').
-#' @param valueLabels character vector that indicate the value labels of  
-#'          \code{data}. Note that if multiple variables are supplied (if \code{data} 
-#'          is a \code{\link{data.frame}}), the value labels must be supplied as 
-#'          \code{list} object (see 'Examples').
-#' @param autoGroupAt numeric value, indicating at which length of unique values of \code{data}, 
-#'          automatic grouping into smaller units is done (see \code{\link[sjmisc]{group_var}}).
-#'          Variables with large numbers of unique values may be too time consuming when 
-#'          a HTML table is created and R would not respond any longer, or the resulting table 
-#'          would be to too long and confusing. Hence it's recommended to group such variables. 
-#'          If \code{autoGroupAt = 50} and \code{varCount} has more than 50 unique values,
-#'          it will be grouped (using the \code{\link[sjmisc]{group_var}} function). 
-#'          Default value for \code{autoGroupAt} is \code{NULL}, i.e. auto-grouping is off.
-#'          See \code{\link[sjmisc]{group_var}} for examples on grouping.
-#' @param sort.frq whether frequencies should be sorted or not. Use \code{"asc"} or \code{"ascending"}
-#'          to sort frequencies ascending, or \code{"desc"} or \code{"descending"} to sort
-#'          frequencies in descending order. By default, \code{sort.frq} is \code{NULL}, i.e.
-#'          frequencies are ordered by values.
-#' @param alternateRowColors logical, if \code{TRUE}, alternating rows are highlighted with a light gray
+#' @param var.labels character vector with variable names, which will be used 
+#'          to label variables in the output.
+#' @param value.labels character vector (or \code{list} of character vectors)
+#'          with value labels of the supplied variables, which will be used 
+#'          to label variable values in the output.
+#' @param altr.row.col logical, if \code{TRUE}, alternating rows are highlighted with a light gray
 #'          background color.
-#' @param stringValue label for the very first table column containing the values (see
-#'          \code{valueLabels}).
-#' @param stringCount label for the first table data column containing the counts. Default is \code{"N"}.
-#' @param stringPerc label for the second table data column containing the raw percentages. Default is \code{"raw \%"}.
-#' @param stringValidPerc String label for the third data table column containing the valid percentages, i.e. the
+#' @param string.val label for the very first table column containing the values (see
+#'          \code{value.labels}).
+#' @param string.cnt label for the first table data column containing the counts. Default is \code{"N"}.
+#' @param string.prc label for the second table data column containing the raw percentages. Default is \code{"raw \%"}.
+#' @param string.vprc String label for the third data table column containing the valid percentages, i.e. the
 #'          count percentage value exluding possible missing values.
-#' @param stringCumPerc String label for the last table data column containing the cumulative percentages.
-#' @param stringMissingValue String label for the last table data row containing missing values.
-#' @param highlightMedian If \code{TRUE}, the table row indicating the median value will
-#'          be highlighted.
-#' @param highlightQuartiles If \code{TRUE}, the table row indicating the lower and upper quartiles will
-#'          be highlighted.
-#' @param skipZeroRows If \code{TRUE}, rows with only zero-values are not printed
+#' @param string.cprc String label for the last table data column containing the cumulative percentages.
+#' @param string.na String label for the last table data row containing missing values.
+#' @param emph.md If \code{TRUE}, the table row indicating the median value will
+#'          be emphasized.
+#' @param emph.quart If \code{TRUE}, the table row indicating the lower and upper quartiles will
+#'          be emphasized.
+#' @param skip.zero If \code{TRUE}, rows with only zero-values are not printed
 #'          (e.g. if a variable has values or levels 1 to 8, and levels / values 
 #'          4 to 6 have no counts, these values would not be printed in the table). 
 #'          Use \code{FALSE} to print also zero-values, or use \code{"auto"} (default)
 #'          to detect whether it makes sense or not to print zero-values (e.g., a variable
 #'          "age" with values from 10 to 100, where at least 25 percent of all possible values have no
 #'          counts, zero-values would be skipped automatically).
-#' @param showSummary If \code{TRUE} (default), a summary row with total and valid N as well as mean and
+#' @param show.summary If \code{TRUE} (default), a summary row with total and valid N as well as mean and
 #'          standard deviation is shown.
-#' @param showSkew If \code{TRUE}, the variable's skewness is added to the summary.
+#' @param show.skew If \code{TRUE}, the variable's skewness is added to the summary.
 #'          The skewness is retrieved from the \code{\link[psych]{describe}}-function 
-#'          of the \pkg{psych}-package.
-#' @param showKurtosis If \code{TRUE}, the variable's kurtosis is added to the summary.
+#'          of the \pkg{psych}-package and indicated by a lower case Greek gamma.
+#' @param show.kurtosis If \code{TRUE}, the variable's kurtosis is added to the summary.
 #'          The kurtosis is retrieved from the \code{\link[psych]{describe}}-function 
-#'          of the \pkg{psych}-package.
-#' @param skewString A character string, which is used as header for the skew 
-#'          column (see \code{showSkew})). Default is lower case Greek gamma.
-#' @param kurtosisString A character string, which is used as header for the 
-#'          kurtosis column (see \code{showKurtosis})). Default is lower case 
-#'          Greek omega.
-#' @param digits amount of digits used for table values. Default is 2.
-#' @param removeStringVectors If \code{TRUE} (default), character vectors / string variables will be removed from
+#'          of the \pkg{psych}-package and indicated by a lower case Greek omega.
+#' @param ignore.strings If \code{TRUE} (default), character vectors / string variables will be removed from
 #'          \code{data} before frequency tables are computed.
-#' @param autoGroupStrings if \code{TRUE} (default), string values in character 
+#' @param auto.grp.strings if \code{TRUE} (default), string values in character 
 #'          vectors (string variables) are automatically grouped based on their 
 #'          similarity. The similarity is estimated with the \pkg{stringdist}-package.
-#'          You can specify a distance-measure via \code{maxStringDist} argument. This argument only
-#'          applies if \code{removeStringVectors} is \code{FALSE}.
-#' @param maxStringDist the allowed distance of string values in a character vector, which indicates
+#'          You can specify a distance-measure via \code{max.string.dist} argument. This argument only
+#'          applies if \code{ignore.strings} is \code{FALSE}.
+#' @param max.string.dist the allowed distance of string values in a character vector, which indicates
 #'          when two string values are merged because they are considered as close enough.
+#'          See \code{auto.grp.strings}.
 #' @param encoding string, indicating the charset encoding used for variable and 
 #'          value labels. Default is \code{NULL}, so encoding will be auto-detected 
 #'          depending on your platform (e.g., \code{"UTF-8"} for Unix and \code{"Windows-1252"} for
 #'          Windows OS). Change encoding if specific chars are not properly displayed (e.g. German umlauts).
 #' @param CSS \code{\link{list}}-object with user-defined style-sheet-definitions, according to the 
 #'          \href{http://www.w3.org/Style/CSS/}{official CSS syntax}. See 'Details'.
-#' @param useViewer If \code{TRUE}, the function tries to show the HTML table in the IDE's viewer pane. If
+#' @param use.viewer If \code{TRUE}, the HTML table is shown in the IDE's viewer pane. If
 #'          \code{FALSE} or no viewer available, the HTML table is opened in a web browser.
 #' @param no.output logical, if \code{TRUE}, the html-output is neither opened in a browser nor shown in
 #'          the viewer pane and not even saved to file. This option is useful when the html output
@@ -108,6 +81,10 @@
 #'            }
 #'            for further use.
 #'          
+#' @inheritParams sjp.glmer
+#' @inheritParams sjp.grpfrq
+#' @inheritParams sjp.frq
+#' 
 #' @note The HTML tables can either be saved as file and manually opened (specify argument \code{file}) or
 #'         they can be saved as temporary files and will be displayed in the RStudio Viewer pane (if working with RStudio)
 #'         or opened with the default web browser. Displaying resp. opening a temporary file is the
@@ -115,7 +92,7 @@
 #' 
 #' @details \bold{How does the \code{CSS}-argument work?}
 #'            \cr \cr
-#'            With the \code{CSS}-paramater, the visual appearance of the tables
+#'            With the \code{CSS}-argument, the visual appearance of the tables
 #'            can be modified. To get an overview of all style-sheet-classnames 
 #'            that are used in this function, see return value \code{page.style} for details. 
 #'            Arguments for this list have following syntax:
@@ -146,49 +123,31 @@
 #' sjt.frq(efc$e42dep)
 #' 
 #' # plot and show frequency table of "e42dep" with labels
-#' sjt.frq(efc$e42dep,
-#'         variableLabels = "Dependency",
-#'         valueLabels = c("independent",
-#'                         "slightly dependent",
-#'                         "moderately dependent",
-#'                         "severely dependent"))
+#' sjt.frq(efc$e42dep, var.labels = "Dependency",
+#'         value.labels = c("independent", "slightly dependent",
+#'                          "moderately dependent", "severely dependent"))
 #' 
 #' # plot frequencies of e42dep, e16sex and c172code in one HTML file
 #' # and show table in RStudio Viewer Pane or default web browser
-#' # Note that valueLabels of multiple variables have to be
+#' # Note that value.labels of multiple variables have to be
 #' # list-objects
 #' sjt.frq(data.frame(efc$e42dep, efc$e16sex, efc$c172code),
-#'         variableLabels = c("Dependency", 
-#'                            "Gender", 
-#'                            "Education"),
-#'         valueLabels = list(c("independent",
-#'                              "slightly dependent",
-#'                              "moderately dependent",
-#'                              "severely dependent"),
-#'                            c("male", "female"),
-#'                            c("low", "mid", "high")))
+#'         var.labels = c("Dependency", "Gender", "Education"),
+#'         value.labels = list(c("independent", "slightly dependent",
+#'                               "moderately dependent", "severely dependent"),
+#'                             c("male", "female"), c("low", "mid", "high")))
 #' 
-#' # -------------------------------
 #' # auto-detection of labels
-#' # due to auto-detection of labels, this works as well
-#' # -------------------------------
 #' sjt.frq(data.frame(efc$e42dep, efc$e16sex, efc$c172code))
 #' 
-#' 
 #' # plot larger scale including zero-counts
 #' # indicating median and quartiles
-#' sjt.frq(efc$neg_c_7,
-#'         highlightMedian = TRUE,
-#'         highlightQuartiles = TRUE)
+#' sjt.frq(efc$neg_c_7, emph.md = TRUE, emph.quart = TRUE)
 #' 
-#' # -------------------------------
 #' # sort frequencies
-#' # -------------------------------
 #' sjt.frq(efc$e42dep, sort.frq = "desc")
 #' 
-#' # -------------------------------- 
 #' # User defined style sheet
-#' # -------------------------------- 
 #' sjt.frq(efc$e42dep,
 #'         CSS = list(css.table = "border: 2px solid;",
 #'                    css.tdata = "border: 1px solid;",
@@ -199,35 +158,33 @@
 #' @import sjmisc
 #' @export
 sjt.frq <- function(data,
-                    file = NULL,
-                    weightBy = NULL,
-                    weightByTitleString = " (weighted)",
-                    variableLabels = NULL,
-                    valueLabels = NULL,
-                    autoGroupAt = NULL,
-                    sort.frq = NULL,
-                    alternateRowColors = FALSE,
-                    stringValue = "value",
-                    stringCount = "N",
-                    stringPerc = "raw %",
-                    stringValidPerc = "valid %",
-                    stringCumPerc = "cumulative %",
-                    stringMissingValue = "missings",
-                    highlightMedian = FALSE,
-                    highlightQuartiles = FALSE,
-                    skipZeroRows = "auto",
-                    showSummary = TRUE,
-                    showSkew = FALSE,
-                    showKurtosis = FALSE,
-                    skewString = "&gamma;",
-                    kurtosisString = "&omega;",
+                    weight.by = NULL,
+                    title.wtd.suffix = " (weighted)",
+                    var.labels = NULL,
+                    value.labels = NULL,
+                    sort.frq = c("none", "asc", "desc"),
+                    altr.row.col = FALSE,
+                    string.val = "value",
+                    string.cnt = "N",
+                    string.prc = "raw %",
+                    string.vprc = "valid %",
+                    string.cprc = "cumulative %",
+                    string.na = "missings",
+                    emph.md = FALSE,
+                    emph.quart = FALSE,
+                    show.summary = TRUE,
+                    show.skew = FALSE,
+                    show.kurtosis = FALSE,
+                    skip.zero = "auto",
+                    ignore.strings = TRUE,
+                    auto.group = NULL,
+                    auto.grp.strings = TRUE,
+                    max.string.dist = 3,
                     digits = 2,
-                    removeStringVectors = TRUE,
-                    autoGroupStrings = TRUE,
-                    maxStringDist = 3,
-                    encoding = NULL,
                     CSS = NULL,
-                    useViewer = TRUE,
+                    encoding = NULL,
+                    file = NULL, 
+                    use.viewer = TRUE,
                     no.output = FALSE,
                     remove.spaces = TRUE) {
   # -------------------------------------
@@ -235,11 +192,15 @@ sjt.frq <- function(data,
   # -------------------------------------
   encoding <- get.encoding(encoding, data)
   # save original value
-  o.skipZeroRows <- skipZeroRows
+  o.skip.zero <- skip.zero
+  # -------------------------------------
+  # match arguments
+  # -------------------------------------
+  sort.frq <- match.arg(sort.frq)
   # -------------------------------------
   # warning
   # -------------------------------------
-  if (!is.null(sort.frq)) message("Sorting may not work when data contains values with zero-counts.")
+  if (!is.null(sort.frq) && sort.frq != "none") message("Sorting may not work when data contains values with zero-counts.")
   # -------------------------------------
   # table init
   # -------------------------------------
@@ -312,7 +273,7 @@ sjt.frq <- function(data,
   # -------------------------------------
   # check if string vectors should be removed
   # -------------------------------------
-  if (removeStringVectors) {
+  if (ignore.strings) {
     # ---------------------------------------
     # check if we have data frame with several variables
     # ---------------------------------------
@@ -320,7 +281,7 @@ sjt.frq <- function(data,
       # remove string variables
       data <- data[, !sapply(data, is.character)]
     } else if (is.character(data)) {
-      stop("argument 'data' is a single string vector, where string vectors should be removed. No data to compute frequency table left. See argument 'removeStringVectors' for details.", call. = FALSE)
+      stop("argument `data` is a single string vector, where string vectors should be removed. No data to compute frequency table left. See argument `ignore.strings` for details.", call. = FALSE)
     }
   }
   # -------------------------------------
@@ -337,31 +298,29 @@ sjt.frq <- function(data,
     # check if any NA-only variables found
     if (length(NAcolumns) > 0) {
       message(sprintf("%i variables have been removed from output, because they contained only NA's: %s", 
-                      length(NAcolumns), 
-                      paste(colnames(data)[NAcolumns], 
-                            collapse = "; ")))
+                      length(NAcolumns), paste(colnames(data)[NAcolumns], collapse = "; ")))
       data <- data[, -NAcolumns]
     }
   }
   # -------------------------------------
   # auto-retrieve variable labels
   # -------------------------------------
-  if (is.null(variableLabels)) {
+  if (is.null(var.labels)) {
     # init variable Labels as list
-    variableLabels <- list()
+    var.labels <- list()
     # check if we have data frame with several variables
     if (is.data.frame(data)) {
       # if yes, iterate each variable
       for (i in 1:ncol(data)) {
         # retrieve variable name attribute
-        variableLabels <-
-          c(variableLabels, sjmisc::get_label(data[[i]], def.value = colnames(data)[i]))
+        var.labels <-
+          c(var.labels, sjmisc::get_label(data[[i]], def.value = colnames(data)[i]))
       }
     # we have a single variable only
     } else {
       # retrieve variable name attribute
-      variableLabels <-
-        c(variableLabels, sjmisc::get_label(data, def.value = deparse(substitute(data))))
+      var.labels <-
+        c(var.labels, sjmisc::get_label(data, def.value = deparse(substitute(data))))
     }
   }
   # -------------------------------------
@@ -372,15 +331,10 @@ sjt.frq <- function(data,
     isString <- is.character(data)
     # check for auto-detection of labels, but only for non-character-vectors
     # characters will be handled later
-    if (is.null(valueLabels) &&
-        !isString)
-      valueLabels <-
-        sjmisc::get_labels(
-          data,
-          attr.only = F,
-          include.values = NULL,
-          include.non.labelled = T
-        )
+    if (is.null(value.labels) && !isString)
+      value.labels <-
+        sjmisc::get_labels(data, attr.only = F, include.values = NULL, 
+                           include.non.labelled = T)
     # copy variable to data frame for unuqie handling
     data <- as.data.frame(data)
     if (isString) {
@@ -395,7 +349,7 @@ sjt.frq <- function(data,
   # -------------------------------------
   # auto-group string vectors
   # -------------------------------------
-  if (autoGroupStrings) {
+  if (auto.grp.strings) {
     # iterate data frame
     for (i in 1:nvar) {
       # get variable
@@ -403,7 +357,8 @@ sjt.frq <- function(data,
       # check if character
       if (is.character(sv)) {
         # group strings
-        data[[i]] <- sjmisc::group_str(sv, maxStringDist, remove.empty = F)
+        data[[i]] <- 
+          sjmisc::group_str(strings = sv, maxdist = max.string.dist, remove.empty = F)
       }
     }
   }
@@ -411,20 +366,20 @@ sjt.frq <- function(data,
   # transform variable and value labels 
   # to list object
   # -------------------------------------
-  if (!is.null(variableLabels) && !is.list(variableLabels)) {
+  if (!is.null(var.labels) && !is.list(var.labels)) {
     # if we have variable labels as vector, convert them to list
-    variableLabels <- as.list(variableLabels)
-  } else if (is.null(variableLabels)) {
+    var.labels <- as.list(var.labels)
+  } else if (is.null(var.labels)) {
     # if we have no variable labels, use column names
     # of data frame
-    variableLabels <- as.list(colnames(data))
+    var.labels <- as.list(colnames(data))
   }
-  if (!is.null(valueLabels) && !is.list(valueLabels)) {
+  if (!is.null(value.labels) && !is.list(value.labels)) {
     # if we have value labels as vector, convert them to list
-    valueLabels <- list(valueLabels)
-  } else if (is.null(valueLabels)) {
+    value.labels <- list(value.labels)
+  } else if (is.null(value.labels)) {
     # create list
-    valueLabels <- list()
+    value.labels <- list()
     # iterate all variables
     for (i in 1:nvar) {
       # retrieve variable
@@ -432,34 +387,30 @@ sjt.frq <- function(data,
       # usually, value labels are NULL if we have string vector. if so
       # set value labels according to values
       if (is.character(dummy)) {
-        valueLabels <- c(valueLabels, list(names(table(dummy))))
+        value.labels <- c(value.labels, list(names(table(dummy))))
       } else {
         # check for auto-detection of labels
         avl <-
-          sjmisc::get_labels(
-            dummy,
-            attr.only = F,
-            include.values = NULL,
-            include.non.labelled = T
-          )
+          sjmisc::get_labels(dummy, attr.only = F, include.values = NULL, 
+                             include.non.labelled = T)
         if (!is.null(avl)) {
-          valueLabels <- c(valueLabels, list(avl))
+          value.labels <- c(value.labels, list(avl))
         } else {
-          valueLabels <- c(valueLabels, 
+          value.labels <- c(value.labels, 
                            list(min(dummy, na.rm = TRUE):max(dummy, na.rm = TRUE)))
         }
       }
       # and add label range to value labels list
-      if (is.null(valueLabels))
-        valueLabels <-
-          c(valueLabels, list(min(dummy, na.rm = TRUE):max(dummy, na.rm = TRUE)))
+      if (is.null(value.labels))
+        value.labels <-
+          c(value.labels, list(min(dummy, na.rm = TRUE):max(dummy, na.rm = TRUE)))
     }
   }
   # -------------------------------------
   # header row of table
   # -------------------------------------
   page.content.list <- list()
-  headerRow <- sprintf("   <tr>\n     <th class=\"thead firsttablerow firsttablecol\">%s</th>\n     <th class=\"thead firsttablerow\">%s</th>\n     <th class=\"thead firsttablerow\">%s</th>\n     <th class=\"thead firsttablerow\">%s</th>\n     <th class=\"thead firsttablerow\">%s</th>\n   </tr>\n\n", stringValue, stringCount, stringPerc, stringValidPerc, stringCumPerc)
+  headerRow <- sprintf("   <tr>\n     <th class=\"thead firsttablerow firsttablecol\">%s</th>\n     <th class=\"thead firsttablerow\">%s</th>\n     <th class=\"thead firsttablerow\">%s</th>\n     <th class=\"thead firsttablerow\">%s</th>\n     <th class=\"thead firsttablerow\">%s</th>\n   </tr>\n\n", string.val, string.cnt, string.prc, string.vprc, string.cprc)
   # -------------------------------------
   # start iterating all variables
   # -------------------------------------
@@ -467,33 +418,19 @@ sjt.frq <- function(data,
     # -----------------------------------------------
     # check for length of unique values and skip if too long
     # -----------------------------------------------
-    if (!is.null(autoGroupAt) &&
-        !is.character(data[[cnt]]) &&
-        length(unique(data[[cnt]])) >= autoGroupAt) {
-      message(sprintf(
-        "Variable %s with %i unique values was grouped...",
-        colnames(data)[cnt],
-        length(unique(data[[cnt]]))
-      ))
-      # check for default auto-group-size or user-defined groups
-      agcnt <- ifelse(autoGroupAt < 30, autoGroupAt, 30)
+    if (!is.null(auto.group) && !is.character(data[[cnt]]) && length(unique(data[[cnt]])) >= auto.group) {
+      message(sprintf("Variable %s with %i unique values was grouped...",
+                      colnames(data)[cnt], length(unique(data[[cnt]]))))
       # group labels
-      valueLabels[[cnt]] <-
-        sjmisc::group_labels(
-          sjmisc::to_value(data[[cnt]], keep.labels = F),
-          groupsize = "auto",
-          groupcount = agcnt
-        )
+      value.labels[[cnt]] <- 
+        sjmisc::group_labels(sjmisc::to_value(data[[cnt]], keep.labels = F),
+                             groupsize = "auto", groupcount = auto.group)
       # group variable
       data[[cnt]] <-
-        sjmisc::group_var(
-          sjmisc::to_value(data[[cnt]], keep.labels = F),
-          groupsize = "auto",
-          as.num = TRUE,
-          groupcount = agcnt
-        )
+        sjmisc::group_var(sjmisc::to_value(data[[cnt]], keep.labels = F),
+                          groupsize = "auto", as.num = TRUE, groupcount = auto.group)
       # set labels
-      data[[cnt]] <- sjmisc::set_labels(data[[cnt]], valueLabels[[cnt]])
+      data[[cnt]] <- sjmisc::set_labels(data[[cnt]], value.labels[[cnt]])
     }
     # -----------------------------------------------
     # prepare data: create frequencies and weight them,
@@ -502,17 +439,16 @@ sjt.frq <- function(data,
     # check if we have a string-vector
     if (is.character(data[[cnt]])) {
       # convert string to numeric
-      orivar <- var <- as.numeric(as.factor(data[[cnt]]))
+      orivar <- varia <- as.numeric(as.factor(data[[cnt]]))
       # here we have numeric or factor variables
     } else {
       # convert to numeric
-      orivar <- var <- sjmisc::to_value(data[[cnt]], 
-                                        keep.labels = F)
+      orivar <- varia <- sjmisc::to_value(data[[cnt]], keep.labels = F)
     }
     # retrieve summary
-    varsummary <- summary(var)
+    varsummary <- summary(varia)
     # retrieve median
-    var.median <- varsummary[[3]]
+    var.median <- stats::median(varia, na.rm = TRUE)
     # retrieve quartiles
     var.lowerq <- round(varsummary[[2]])
     var.upperq <- round(varsummary[[5]])
@@ -520,26 +456,26 @@ sjt.frq <- function(data,
     # create frequency data frame
     #---------------------------------------------------
     df.frq <- create.frq.df(data[[cnt]],
-                            breakLabelsAt = Inf,
+                            wrap.labels = Inf,
                             order.frq = sort.frq,
                             round.prz = digits,
                             na.rm = F, 
-                            weightBy = weightBy)
+                            weight.by = weight.by)
     df <- df.frq$mydat
     #---------------------------------------------------
     # auto-set skipping zero-rows?
     #---------------------------------------------------
-    if (!is.logical(o.skipZeroRows)) {
+    if (!is.logical(o.skip.zero)) {
       # retrieve range of values
-      vonbis <- max(var, na.rm = T) - min(var, na.rm = T)
+      vonbis <- max(varia, na.rm = T) - min(varia, na.rm = T)
       # retrieve count of unique values
-      anzval <- stats::na.omit(unique(var))
+      anzval <- stats::na.omit(unique(varia))
       # check proportion of possible values and actual values
       # if we have more than 25% of zero-values, or if we have
       # in general a large variable range, skip zero-rows.
-      skipZeroRows <- ((100 * anzval / vonbis) < 75) || (anzval > 20)
+      skip.zero <- ((100 * anzval / vonbis) < 75) || (anzval > 20)
     } else {
-      skipZeroRows <- o.skipZeroRows
+      skip.zero <- o.skip.zero
     }
     # save labels
     vallab <- df.frq$labels
@@ -552,10 +488,10 @@ sjt.frq <- function(data,
     # -------------------------------------
     # retrieve variable label
     # -------------------------------------
-    varlab <- variableLabels[[cnt]]
+    varlab <- var.labels[[cnt]]
     # if we have weighted values, say that in diagram's title
-    if (!is.null(weightBy)) {
-      varlab <- paste(varlab, weightByTitleString, sep = "")
+    if (!is.null(weight.by)) {
+      varlab <- paste(varlab, title.wtd.suffix, sep = "")
     }
     # -------------------------------------
     # table caption, variable label
@@ -573,7 +509,7 @@ sjt.frq <- function(data,
       # -------------------------------------
       # check if to skip zero rows
       # -------------------------------------
-      if (skipZeroRows && zerorow) {
+      if (skip.zero && zerorow) {
         # nothing here...
       } else {
         # -------------------------------------
@@ -585,37 +521,31 @@ sjt.frq <- function(data,
         # init default values
         rowstring <- ""
         # init default value for alternating colors
-        if (alternateRowColors) rowstring <- ifelse(sjmisc::is_even(j), " arc", "")
+        if (altr.row.col) rowstring <- ifelse(sjmisc::is_even(j), " arc", "")
         rowcss <- rowstring
         # check whether we have median row and whether it should be highlighted
-        if (highlightMedian && ((j + df.frq$minval) == (var.median + 1))) {
+        if (emph.md && ((j + df.frq$minval) == (var.median + 1))) {
           rowcss <- sprintf(" mdrow%s", rowstring)
         }
         # check whether we have lower quartile and whether it should be highlighted
-        else {
-          if (highlightQuartiles) {
-            if (((j + df.frq$minval) == (var.lowerq + 1)) || ((j + df.frq$minval) == (var.upperq + 1))) {
-              rowcss <- sprintf(" qrow%s", rowstring)
-            }
+        else if (emph.quart) {
+          if (((j + df.frq$minval) == (var.lowerq + 1)) || ((j + df.frq$minval) == (var.upperq + 1))) {
+            rowcss <- sprintf(" qrow%s", rowstring)
           }
         }
         # value label
         page.content <- paste(page.content, 
                               sprintf("  <tr>\n     <td class=\"tdata leftalign firsttablecol%s\">%s</td>\n", 
-                                      rowcss, 
-                                      vallab[j]))
+                                      rowcss, vallab[j]))
         # cell values, first value is integer
         page.content <- paste(page.content, 
                               sprintf("    <td class=\"tdata centeralign%s\">%i</td>\n", 
-                                      rowcss, 
-                                      as.integer(datarow$frq)))
+                                      rowcss, as.integer(datarow$frq)))
         for (i in 8:10) {
           # following values are float
           page.content <- paste(page.content, 
                                 sprintf("    <td class=\"tdata centeralign%s\">%.*f</td>\n", 
-                                        rowcss, 
-                                        digits,
-                                        datarow[i]))
+                                        rowcss, digits, datarow[i]))
         }
         # close row-tag
         page.content <- paste(page.content, "  </tr>\n", "\n")
@@ -630,7 +560,7 @@ sjt.frq <- function(data,
     # write table data row
     # -------------------------------------
     # value label
-    page.content <- paste(page.content, sprintf("  <tr>\n     <td class=\"tdata leftalign lasttablerow firsttablecol\">%s</td>\n", stringMissingValue))
+    page.content <- paste(page.content, sprintf("  <tr>\n     <td class=\"tdata leftalign lasttablerow firsttablecol\">%s</td>\n", string.na))
     # cell values, first value is integer
     page.content <- paste(page.content, sprintf("    <td class=\"tdata centeralign lasttablerow\">%i</td>\n", as.integer(datarow$frq)))
     # 2nd value is float. we don't need 3rd and 4th value as they are always 0 and 100
@@ -638,42 +568,32 @@ sjt.frq <- function(data,
     # -------------------------------------
     # add info for mean, standard deviation
     # -------------------------------------
-    if (showSummary) {
+    if (show.summary) {
       # sum of frequencies is total N. Use these numbers
-      # instead of "length(var)", because weighted data
+      # instead of "length(varia)", because weighted data
       # has different N
       vartot <- sum(df$frq, na.rm = T)
       # last element in df$frq is amount of missings,
       # so substract from total to get valid N
       varvalid <- vartot - df$frq[nrow(df)]
-      if (is.null(weightBy)) {
+      if (is.null(weight.by)) {
         mw <- mean(orivar, na.rm = TRUE)
         sum_var <- orivar
       } else {
-        mw <- stats::weighted.mean(orivar, weightBy, na.rm = TRUE)
-        sum_var <- sjmisc::weight(orivar, weightBy)
+        mw <- stats::weighted.mean(orivar, weight.by, na.rm = TRUE)
+        sum_var <- sjmisc::weight(orivar, weight.by)
       }
       descr <- ""
-      if (showSkew || showKurtosis) {
+      if (show.skew || show.kurtosis) {
         pstat <- psych::describe(data.frame(sum_var))
-        if (showSkew) descr <- sprintf(" &middot; %s=%.*f", 
-                                       skewString, 
-                                       digits,
-                                       pstat$skew)
-        if (showKurtosis) descr <- sprintf("%s &middot; %s=%.*f", 
-                                           descr, 
-                                           kurtosisString, 
-                                           digits,
-                                           pstat$kurtosis)
+        if (show.skew) descr <- sprintf(" &middot; &gamma;=%.*f", digits, pstat$skew)
+        if (show.kurtosis) descr <- sprintf("%s &middot; &omega;=%.*f", descr, 
+                                            digits, pstat$kurtosis)
       }
-      page.content <- paste(page.content, sprintf("  </tr>\n  <tr>\n    <td class=\"tdata summary\" colspan=\"5\">total N=%i &middot; valid N=%i &middot; x&#772;=%.*f &middot; &sigma;=%.*f%s</td>\n", 
-                                                  vartot, 
-                                                  varvalid, 
-                                                  digits,
-                                                  mw, 
-                                                  digits,
-                                                  sd(sum_var, na.rm = TRUE), 
-                                                  descr))
+      page.content <- paste(page.content, 
+                            sprintf("  </tr>\n  <tr>\n    <td class=\"tdata summary\" colspan=\"5\">total N=%i &middot; valid N=%i &middot; x&#772;=%.*f &middot; &sigma;=%.*f%s</td>\n", 
+                                    vartot, varvalid, digits, mw, digits,
+                                    stats::sd(sum_var, na.rm = TRUE), descr))
     }
     # -------------------------------------
     # finish table
@@ -703,8 +623,7 @@ sjt.frq <- function(data,
   if (nvar > 1) {
     knitr <- c()
     for (i in 1:length(page.content.list)) {
-      knitr <- paste0(knitr, 
-                      page.content.list[[i]], 
+      knitr <- paste0(knitr, page.content.list[[i]], 
                       sprintf("\n<p style=\"%s\">&nbsp;</p>\n", css.abstand))
     }
   } else {
@@ -742,7 +661,7 @@ sjt.frq <- function(data,
   # -------------------------------------
   # check if html-content should be outputted
   # -------------------------------------
-  out.html.table(no.output, file, knitr, toWrite, useViewer)
+  out.html.table(no.output, file, knitr, toWrite, use.viewer)
   # -------------------------------------
   # return results
   # -------------------------------------
